# esi_client

ESIClient - the Ruby gem for the EVE Swagger Interface

An OpenAPI for EVE Online

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.7.5
- Package version: 1.4.0
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build esi_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./esi_client-1.4.0.gem
```
(for development, run `gem install --dev ./esi_client-1.4.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'esi_client', '~> 1.4.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/EmberSands/esi_client, then add the following in the Gemfile:

    gem 'esi_client', :git => 'https://github.com/EmberSands/esi_client.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'esi_client'

api_instance = ESIClient::AllianceApi.new

opts = { 
  datasource: 'tranquility', # String | The server name you would like data from
  user_agent: 'user_agent_example', # String | Client identifier, takes precedence over headers
  x_user_agent: 'x_user_agent_example' # String | Client identifier, takes precedence over User-Agent
}

begin
  #List all alliances
  result = api_instance.get_alliances(opts)
  p result
rescue ESIClient::ApiError => e
  puts "Exception when calling AllianceApi->get_alliances: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://esi.tech.ccp.is*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ESIClient::AllianceApi* | [**get_alliances**](docs/AllianceApi.md#get_alliances) | **GET** /v1/alliances/ | List all alliances
*ESIClient::AllianceApi* | [**get_alliances_alliance_id**](docs/AllianceApi.md#get_alliances_alliance_id) | **GET** /v3/alliances/{alliance_id}/ | Get alliance information
*ESIClient::AllianceApi* | [**get_alliances_alliance_id_corporations**](docs/AllianceApi.md#get_alliances_alliance_id_corporations) | **GET** /v1/alliances/{alliance_id}/corporations/ | List alliance's corporations
*ESIClient::AllianceApi* | [**get_alliances_alliance_id_icons**](docs/AllianceApi.md#get_alliances_alliance_id_icons) | **GET** /v1/alliances/{alliance_id}/icons/ | Get alliance icon
*ESIClient::AllianceApi* | [**get_alliances_names**](docs/AllianceApi.md#get_alliances_names) | **GET** /v2/alliances/names/ | Get alliance names
*ESIClient::AssetsApi* | [**get_characters_character_id_assets**](docs/AssetsApi.md#get_characters_character_id_assets) | **GET** /v3/characters/{character_id}/assets/ | Get character assets
*ESIClient::AssetsApi* | [**get_corporations_corporation_id_assets**](docs/AssetsApi.md#get_corporations_corporation_id_assets) | **GET** /v2/corporations/{corporation_id}/assets/ | Get corporation assets
*ESIClient::AssetsApi* | [**post_characters_character_id_assets_locations**](docs/AssetsApi.md#post_characters_character_id_assets_locations) | **POST** /v2/characters/{character_id}/assets/locations/ | Get character asset locations
*ESIClient::AssetsApi* | [**post_characters_character_id_assets_names**](docs/AssetsApi.md#post_characters_character_id_assets_names) | **POST** /v1/characters/{character_id}/assets/names/ | Get character asset names
*ESIClient::AssetsApi* | [**post_corporations_corporation_id_assets_locations**](docs/AssetsApi.md#post_corporations_corporation_id_assets_locations) | **POST** /v2/corporations/{corporation_id}/assets/locations/ | Get corporation asset locations
*ESIClient::AssetsApi* | [**post_corporations_corporation_id_assets_names**](docs/AssetsApi.md#post_corporations_corporation_id_assets_names) | **POST** /v1/corporations/{corporation_id}/assets/names/ | Get coporation asset names
*ESIClient::BookmarksApi* | [**get_characters_character_id_bookmarks**](docs/BookmarksApi.md#get_characters_character_id_bookmarks) | **GET** /v2/characters/{character_id}/bookmarks/ | List bookmarks
*ESIClient::BookmarksApi* | [**get_characters_character_id_bookmarks_folders**](docs/BookmarksApi.md#get_characters_character_id_bookmarks_folders) | **GET** /v2/characters/{character_id}/bookmarks/folders/ | List bookmark folders
*ESIClient::BookmarksApi* | [**get_corporations_corporation_id_bookmarks**](docs/BookmarksApi.md#get_corporations_corporation_id_bookmarks) | **GET** /v1/corporations/{corporation_id}/bookmarks/ | List corporation bookmarks
*ESIClient::BookmarksApi* | [**get_corporations_corporation_id_bookmarks_folders**](docs/BookmarksApi.md#get_corporations_corporation_id_bookmarks_folders) | **GET** /v1/corporations/{corporation_id}/bookmarks/folders/ | List corporation bookmark folders
*ESIClient::CalendarApi* | [**get_characters_character_id_calendar**](docs/CalendarApi.md#get_characters_character_id_calendar) | **GET** /v1/characters/{character_id}/calendar/ | List calendar event summaries
*ESIClient::CalendarApi* | [**get_characters_character_id_calendar_event_id**](docs/CalendarApi.md#get_characters_character_id_calendar_event_id) | **GET** /v3/characters/{character_id}/calendar/{event_id}/ | Get an event
*ESIClient::CalendarApi* | [**get_characters_character_id_calendar_event_id_attendees**](docs/CalendarApi.md#get_characters_character_id_calendar_event_id_attendees) | **GET** /v1/characters/{character_id}/calendar/{event_id}/attendees/ | Get attendees
*ESIClient::CalendarApi* | [**put_characters_character_id_calendar_event_id**](docs/CalendarApi.md#put_characters_character_id_calendar_event_id) | **PUT** /v3/characters/{character_id}/calendar/{event_id}/ | Respond to an event
*ESIClient::CharacterApi* | [**get_characters_character_id**](docs/CharacterApi.md#get_characters_character_id) | **GET** /v4/characters/{character_id}/ | Get character's public information
*ESIClient::CharacterApi* | [**get_characters_character_id_agents_research**](docs/CharacterApi.md#get_characters_character_id_agents_research) | **GET** /v1/characters/{character_id}/agents_research/ | Get agents research
*ESIClient::CharacterApi* | [**get_characters_character_id_blueprints**](docs/CharacterApi.md#get_characters_character_id_blueprints) | **GET** /v2/characters/{character_id}/blueprints/ | Get blueprints
*ESIClient::CharacterApi* | [**get_characters_character_id_chat_channels**](docs/CharacterApi.md#get_characters_character_id_chat_channels) | **GET** /v1/characters/{character_id}/chat_channels/ | Get chat channels
*ESIClient::CharacterApi* | [**get_characters_character_id_corporationhistory**](docs/CharacterApi.md#get_characters_character_id_corporationhistory) | **GET** /v1/characters/{character_id}/corporationhistory/ | Get corporation history
*ESIClient::CharacterApi* | [**get_characters_character_id_fatigue**](docs/CharacterApi.md#get_characters_character_id_fatigue) | **GET** /v1/characters/{character_id}/fatigue/ | Get jump fatigue
*ESIClient::CharacterApi* | [**get_characters_character_id_medals**](docs/CharacterApi.md#get_characters_character_id_medals) | **GET** /v1/characters/{character_id}/medals/ | Get medals
*ESIClient::CharacterApi* | [**get_characters_character_id_notifications**](docs/CharacterApi.md#get_characters_character_id_notifications) | **GET** /v1/characters/{character_id}/notifications/ | Get character notifications
*ESIClient::CharacterApi* | [**get_characters_character_id_notifications_contacts**](docs/CharacterApi.md#get_characters_character_id_notifications_contacts) | **GET** /v1/characters/{character_id}/notifications/contacts/ | Get new contact notifications
*ESIClient::CharacterApi* | [**get_characters_character_id_portrait**](docs/CharacterApi.md#get_characters_character_id_portrait) | **GET** /v2/characters/{character_id}/portrait/ | Get character portraits
*ESIClient::CharacterApi* | [**get_characters_character_id_roles**](docs/CharacterApi.md#get_characters_character_id_roles) | **GET** /v2/characters/{character_id}/roles/ | Get character corporation roles
*ESIClient::CharacterApi* | [**get_characters_character_id_standings**](docs/CharacterApi.md#get_characters_character_id_standings) | **GET** /v1/characters/{character_id}/standings/ | Get standings
*ESIClient::CharacterApi* | [**get_characters_character_id_stats**](docs/CharacterApi.md#get_characters_character_id_stats) | **GET** /v2/characters/{character_id}/stats/ | Yearly aggregate stats
*ESIClient::CharacterApi* | [**get_characters_character_id_titles**](docs/CharacterApi.md#get_characters_character_id_titles) | **GET** /v1/characters/{character_id}/titles/ | Get character corporation titles
*ESIClient::CharacterApi* | [**get_characters_names**](docs/CharacterApi.md#get_characters_names) | **GET** /v1/characters/names/ | Get character names
*ESIClient::CharacterApi* | [**post_characters_affiliation**](docs/CharacterApi.md#post_characters_affiliation) | **POST** /v1/characters/affiliation/ | Character affiliation
*ESIClient::CharacterApi* | [**post_characters_character_id_cspa**](docs/CharacterApi.md#post_characters_character_id_cspa) | **POST** /v4/characters/{character_id}/cspa/ | Calculate a CSPA charge cost
*ESIClient::ClonesApi* | [**get_characters_character_id_clones**](docs/ClonesApi.md#get_characters_character_id_clones) | **GET** /v3/characters/{character_id}/clones/ | Get clones
*ESIClient::ClonesApi* | [**get_characters_character_id_implants**](docs/ClonesApi.md#get_characters_character_id_implants) | **GET** /v1/characters/{character_id}/implants/ | Get active implants
*ESIClient::ContactsApi* | [**delete_characters_character_id_contacts**](docs/ContactsApi.md#delete_characters_character_id_contacts) | **DELETE** /v2/characters/{character_id}/contacts/ | Delete contacts
*ESIClient::ContactsApi* | [**get_alliances_alliance_id_contacts**](docs/ContactsApi.md#get_alliances_alliance_id_contacts) | **GET** /v1/alliances/{alliance_id}/contacts/ | Get alliance contacts
*ESIClient::ContactsApi* | [**get_characters_character_id_contacts**](docs/ContactsApi.md#get_characters_character_id_contacts) | **GET** /v1/characters/{character_id}/contacts/ | Get contacts
*ESIClient::ContactsApi* | [**get_characters_character_id_contacts_labels**](docs/ContactsApi.md#get_characters_character_id_contacts_labels) | **GET** /v1/characters/{character_id}/contacts/labels/ | Get contact labels
*ESIClient::ContactsApi* | [**get_corporations_corporation_id_contacts**](docs/ContactsApi.md#get_corporations_corporation_id_contacts) | **GET** /v1/corporations/{corporation_id}/contacts/ | Get corporation contacts
*ESIClient::ContactsApi* | [**post_characters_character_id_contacts**](docs/ContactsApi.md#post_characters_character_id_contacts) | **POST** /v1/characters/{character_id}/contacts/ | Add contacts
*ESIClient::ContactsApi* | [**put_characters_character_id_contacts**](docs/ContactsApi.md#put_characters_character_id_contacts) | **PUT** /v1/characters/{character_id}/contacts/ | Edit contacts
*ESIClient::ContractsApi* | [**get_characters_character_id_contracts**](docs/ContractsApi.md#get_characters_character_id_contracts) | **GET** /v1/characters/{character_id}/contracts/ | Get contracts
*ESIClient::ContractsApi* | [**get_characters_character_id_contracts_contract_id_bids**](docs/ContractsApi.md#get_characters_character_id_contracts_contract_id_bids) | **GET** /v1/characters/{character_id}/contracts/{contract_id}/bids/ | Get contract bids
*ESIClient::ContractsApi* | [**get_characters_character_id_contracts_contract_id_items**](docs/ContractsApi.md#get_characters_character_id_contracts_contract_id_items) | **GET** /v1/characters/{character_id}/contracts/{contract_id}/items/ | Get contract items
*ESIClient::ContractsApi* | [**get_corporations_corporation_id_contracts**](docs/ContractsApi.md#get_corporations_corporation_id_contracts) | **GET** /v1/corporations/{corporation_id}/contracts/ | Get coporation contracts
*ESIClient::ContractsApi* | [**get_corporations_corporation_id_contracts_contract_id_bids**](docs/ContractsApi.md#get_corporations_corporation_id_contracts_contract_id_bids) | **GET** /v1/corporations/{corporation_id}/contracts/{contract_id}/bids/ | Get corporation contract bids
*ESIClient::ContractsApi* | [**get_corporations_corporation_id_contracts_contract_id_items**](docs/ContractsApi.md#get_corporations_corporation_id_contracts_contract_id_items) | **GET** /v1/corporations/{corporation_id}/contracts/{contract_id}/items/ | Get corporation contract items
*ESIClient::CorporationApi* | [**get_corporations_corporation_id**](docs/CorporationApi.md#get_corporations_corporation_id) | **GET** /v4/corporations/{corporation_id}/ | Get corporation information
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_alliancehistory**](docs/CorporationApi.md#get_corporations_corporation_id_alliancehistory) | **GET** /v2/corporations/{corporation_id}/alliancehistory/ | Get alliance history
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_blueprints**](docs/CorporationApi.md#get_corporations_corporation_id_blueprints) | **GET** /v1/corporations/{corporation_id}/blueprints/ | Get corporation blueprints
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_containers_logs**](docs/CorporationApi.md#get_corporations_corporation_id_containers_logs) | **GET** /v1/corporations/{corporation_id}/containers/logs/ | Get all corporation ALSC logs
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_divisions**](docs/CorporationApi.md#get_corporations_corporation_id_divisions) | **GET** /v1/corporations/{corporation_id}/divisions/ | Get corporation divisions
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_facilities**](docs/CorporationApi.md#get_corporations_corporation_id_facilities) | **GET** /v1/corporations/{corporation_id}/facilities/ | Get corporation facilities
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_icons**](docs/CorporationApi.md#get_corporations_corporation_id_icons) | **GET** /v1/corporations/{corporation_id}/icons/ | Get corporation icon
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_medals**](docs/CorporationApi.md#get_corporations_corporation_id_medals) | **GET** /v1/corporations/{corporation_id}/medals/ | Get corporation medals
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_medals_issued**](docs/CorporationApi.md#get_corporations_corporation_id_medals_issued) | **GET** /v1/corporations/{corporation_id}/medals/issued/ | Get corporation issued medals
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_members**](docs/CorporationApi.md#get_corporations_corporation_id_members) | **GET** /v3/corporations/{corporation_id}/members/ | Get corporation members
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_members_limit**](docs/CorporationApi.md#get_corporations_corporation_id_members_limit) | **GET** /v1/corporations/{corporation_id}/members/limit/ | Get corporation member limit
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_members_titles**](docs/CorporationApi.md#get_corporations_corporation_id_members_titles) | **GET** /v1/corporations/{corporation_id}/members/titles/ | Get corporation's members' titles
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_membertracking**](docs/CorporationApi.md#get_corporations_corporation_id_membertracking) | **GET** /v1/corporations/{corporation_id}/membertracking/ | Track corporation members
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_outposts**](docs/CorporationApi.md#get_corporations_corporation_id_outposts) | **GET** /v1/corporations/{corporation_id}/outposts/ | Get corporation outposts
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_outposts_outpost_id**](docs/CorporationApi.md#get_corporations_corporation_id_outposts_outpost_id) | **GET** /v1/corporations/{corporation_id}/outposts/{outpost_id}/ | Get corporation outpost details
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_roles**](docs/CorporationApi.md#get_corporations_corporation_id_roles) | **GET** /v1/corporations/{corporation_id}/roles/ | Get corporation member roles
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_roles_history**](docs/CorporationApi.md#get_corporations_corporation_id_roles_history) | **GET** /v1/corporations/{corporation_id}/roles/history/ | Get corporation member roles history
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_shareholders**](docs/CorporationApi.md#get_corporations_corporation_id_shareholders) | **GET** /v1/corporations/{corporation_id}/shareholders/ | Get corporation shareholders
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_standings**](docs/CorporationApi.md#get_corporations_corporation_id_standings) | **GET** /v1/corporations/{corporation_id}/standings/ | Get corporation standings
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_starbases**](docs/CorporationApi.md#get_corporations_corporation_id_starbases) | **GET** /v1/corporations/{corporation_id}/starbases/ | Get corporation starbases (POSes)
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_starbases_starbase_id**](docs/CorporationApi.md#get_corporations_corporation_id_starbases_starbase_id) | **GET** /v1/corporations/{corporation_id}/starbases/{starbase_id}/ | Get starbase (POS) detail
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_structures**](docs/CorporationApi.md#get_corporations_corporation_id_structures) | **GET** /v2/corporations/{corporation_id}/structures/ | Get corporation structures
*ESIClient::CorporationApi* | [**get_corporations_corporation_id_titles**](docs/CorporationApi.md#get_corporations_corporation_id_titles) | **GET** /v1/corporations/{corporation_id}/titles/ | Get corporation titles
*ESIClient::CorporationApi* | [**get_corporations_names**](docs/CorporationApi.md#get_corporations_names) | **GET** /v2/corporations/names/ | Get corporation names
*ESIClient::CorporationApi* | [**get_corporations_npccorps**](docs/CorporationApi.md#get_corporations_npccorps) | **GET** /v1/corporations/npccorps/ | Get npc corporations
*ESIClient::DogmaApi* | [**get_dogma_attributes**](docs/DogmaApi.md#get_dogma_attributes) | **GET** /v1/dogma/attributes/ | Get attributes
*ESIClient::DogmaApi* | [**get_dogma_attributes_attribute_id**](docs/DogmaApi.md#get_dogma_attributes_attribute_id) | **GET** /v1/dogma/attributes/{attribute_id}/ | Get attribute information
*ESIClient::DogmaApi* | [**get_dogma_effects**](docs/DogmaApi.md#get_dogma_effects) | **GET** /v1/dogma/effects/ | Get effects
*ESIClient::DogmaApi* | [**get_dogma_effects_effect_id**](docs/DogmaApi.md#get_dogma_effects_effect_id) | **GET** /v2/dogma/effects/{effect_id}/ | Get effect information
*ESIClient::FactionWarfareApi* | [**get_characters_character_id_fw_stats**](docs/FactionWarfareApi.md#get_characters_character_id_fw_stats) | **GET** /v1/characters/{character_id}/fw/stats/ | Overview of a character involved in faction warfare
*ESIClient::FactionWarfareApi* | [**get_corporations_corporation_id_fw_stats**](docs/FactionWarfareApi.md#get_corporations_corporation_id_fw_stats) | **GET** /v1/corporations/{corporation_id}/fw/stats/ | Overview of a corporation involved in faction warfare
*ESIClient::FactionWarfareApi* | [**get_fw_leaderboards**](docs/FactionWarfareApi.md#get_fw_leaderboards) | **GET** /v1/fw/leaderboards/ | List of the top factions in faction warfare
*ESIClient::FactionWarfareApi* | [**get_fw_leaderboards_characters**](docs/FactionWarfareApi.md#get_fw_leaderboards_characters) | **GET** /v1/fw/leaderboards/characters/ | List of the top pilots in faction warfare
*ESIClient::FactionWarfareApi* | [**get_fw_leaderboards_corporations**](docs/FactionWarfareApi.md#get_fw_leaderboards_corporations) | **GET** /v1/fw/leaderboards/corporations/ | List of the top corporations in faction warfare
*ESIClient::FactionWarfareApi* | [**get_fw_stats**](docs/FactionWarfareApi.md#get_fw_stats) | **GET** /v1/fw/stats/ | An overview of statistics about factions involved in faction warfare
*ESIClient::FactionWarfareApi* | [**get_fw_systems**](docs/FactionWarfareApi.md#get_fw_systems) | **GET** /v1/fw/systems/ | Ownership of faction warfare systems
*ESIClient::FactionWarfareApi* | [**get_fw_wars**](docs/FactionWarfareApi.md#get_fw_wars) | **GET** /v1/fw/wars/ | Data about which NPC factions are at war
*ESIClient::FittingsApi* | [**delete_characters_character_id_fittings_fitting_id**](docs/FittingsApi.md#delete_characters_character_id_fittings_fitting_id) | **DELETE** /v1/characters/{character_id}/fittings/{fitting_id}/ | Delete fitting
*ESIClient::FittingsApi* | [**get_characters_character_id_fittings**](docs/FittingsApi.md#get_characters_character_id_fittings) | **GET** /v1/characters/{character_id}/fittings/ | Get fittings
*ESIClient::FittingsApi* | [**post_characters_character_id_fittings**](docs/FittingsApi.md#post_characters_character_id_fittings) | **POST** /v1/characters/{character_id}/fittings/ | Create fitting
*ESIClient::FleetsApi* | [**delete_fleets_fleet_id_members_member_id**](docs/FleetsApi.md#delete_fleets_fleet_id_members_member_id) | **DELETE** /v1/fleets/{fleet_id}/members/{member_id}/ | Kick fleet member
*ESIClient::FleetsApi* | [**delete_fleets_fleet_id_squads_squad_id**](docs/FleetsApi.md#delete_fleets_fleet_id_squads_squad_id) | **DELETE** /v1/fleets/{fleet_id}/squads/{squad_id}/ | Delete fleet squad
*ESIClient::FleetsApi* | [**delete_fleets_fleet_id_wings_wing_id**](docs/FleetsApi.md#delete_fleets_fleet_id_wings_wing_id) | **DELETE** /v1/fleets/{fleet_id}/wings/{wing_id}/ | Delete fleet wing
*ESIClient::FleetsApi* | [**get_characters_character_id_fleet**](docs/FleetsApi.md#get_characters_character_id_fleet) | **GET** /v1/characters/{character_id}/fleet/ | Get character fleet info
*ESIClient::FleetsApi* | [**get_fleets_fleet_id**](docs/FleetsApi.md#get_fleets_fleet_id) | **GET** /v1/fleets/{fleet_id}/ | Get fleet information
*ESIClient::FleetsApi* | [**get_fleets_fleet_id_members**](docs/FleetsApi.md#get_fleets_fleet_id_members) | **GET** /v1/fleets/{fleet_id}/members/ | Get fleet members
*ESIClient::FleetsApi* | [**get_fleets_fleet_id_wings**](docs/FleetsApi.md#get_fleets_fleet_id_wings) | **GET** /v1/fleets/{fleet_id}/wings/ | Get fleet wings
*ESIClient::FleetsApi* | [**post_fleets_fleet_id_members**](docs/FleetsApi.md#post_fleets_fleet_id_members) | **POST** /v1/fleets/{fleet_id}/members/ | Create fleet invitation
*ESIClient::FleetsApi* | [**post_fleets_fleet_id_wings**](docs/FleetsApi.md#post_fleets_fleet_id_wings) | **POST** /v1/fleets/{fleet_id}/wings/ | Create fleet wing
*ESIClient::FleetsApi* | [**post_fleets_fleet_id_wings_wing_id_squads**](docs/FleetsApi.md#post_fleets_fleet_id_wings_wing_id_squads) | **POST** /v1/fleets/{fleet_id}/wings/{wing_id}/squads/ | Create fleet squad
*ESIClient::FleetsApi* | [**put_fleets_fleet_id**](docs/FleetsApi.md#put_fleets_fleet_id) | **PUT** /v1/fleets/{fleet_id}/ | Update fleet
*ESIClient::FleetsApi* | [**put_fleets_fleet_id_members_member_id**](docs/FleetsApi.md#put_fleets_fleet_id_members_member_id) | **PUT** /v1/fleets/{fleet_id}/members/{member_id}/ | Move fleet member
*ESIClient::FleetsApi* | [**put_fleets_fleet_id_squads_squad_id**](docs/FleetsApi.md#put_fleets_fleet_id_squads_squad_id) | **PUT** /v1/fleets/{fleet_id}/squads/{squad_id}/ | Rename fleet squad
*ESIClient::FleetsApi* | [**put_fleets_fleet_id_wings_wing_id**](docs/FleetsApi.md#put_fleets_fleet_id_wings_wing_id) | **PUT** /v1/fleets/{fleet_id}/wings/{wing_id}/ | Rename fleet wing
*ESIClient::IncursionsApi* | [**get_incursions**](docs/IncursionsApi.md#get_incursions) | **GET** /v1/incursions/ | List incursions
*ESIClient::IndustryApi* | [**get_characters_character_id_industry_jobs**](docs/IndustryApi.md#get_characters_character_id_industry_jobs) | **GET** /v1/characters/{character_id}/industry/jobs/ | List character industry jobs
*ESIClient::IndustryApi* | [**get_characters_character_id_mining**](docs/IndustryApi.md#get_characters_character_id_mining) | **GET** /v1/characters/{character_id}/mining/ | Character mining ledger
*ESIClient::IndustryApi* | [**get_corporation_corporation_id_mining_extractions**](docs/IndustryApi.md#get_corporation_corporation_id_mining_extractions) | **GET** /v1/corporation/{corporation_id}/mining/extractions/ | Moon extraction timers
*ESIClient::IndustryApi* | [**get_corporation_corporation_id_mining_observers**](docs/IndustryApi.md#get_corporation_corporation_id_mining_observers) | **GET** /v1/corporation/{corporation_id}/mining/observers/ | Corporation mining observers
*ESIClient::IndustryApi* | [**get_corporation_corporation_id_mining_observers_observer_id**](docs/IndustryApi.md#get_corporation_corporation_id_mining_observers_observer_id) | **GET** /v1/corporation/{corporation_id}/mining/observers/{observer_id}/ | Observed corporation mining
*ESIClient::IndustryApi* | [**get_corporations_corporation_id_industry_jobs**](docs/IndustryApi.md#get_corporations_corporation_id_industry_jobs) | **GET** /v1/corporations/{corporation_id}/industry/jobs/ | List corporation industry jobs
*ESIClient::IndustryApi* | [**get_industry_facilities**](docs/IndustryApi.md#get_industry_facilities) | **GET** /v1/industry/facilities/ | List industry facilities
*ESIClient::IndustryApi* | [**get_industry_systems**](docs/IndustryApi.md#get_industry_systems) | **GET** /v1/industry/systems/ | List solar system cost indices
*ESIClient::InsuranceApi* | [**get_insurance_prices**](docs/InsuranceApi.md#get_insurance_prices) | **GET** /v1/insurance/prices/ | List insurance levels
*ESIClient::KillmailsApi* | [**get_characters_character_id_killmails_recent**](docs/KillmailsApi.md#get_characters_character_id_killmails_recent) | **GET** /v1/characters/{character_id}/killmails/recent/ | Get character kills and losses
*ESIClient::KillmailsApi* | [**get_corporations_corporation_id_killmails_recent**](docs/KillmailsApi.md#get_corporations_corporation_id_killmails_recent) | **GET** /v1/corporations/{corporation_id}/killmails/recent/ | Get corporation kills and losses
*ESIClient::KillmailsApi* | [**get_killmails_killmail_id_killmail_hash**](docs/KillmailsApi.md#get_killmails_killmail_id_killmail_hash) | **GET** /v1/killmails/{killmail_id}/{killmail_hash}/ | Get a single killmail
*ESIClient::LocationApi* | [**get_characters_character_id_location**](docs/LocationApi.md#get_characters_character_id_location) | **GET** /v1/characters/{character_id}/location/ | Get character location
*ESIClient::LocationApi* | [**get_characters_character_id_online**](docs/LocationApi.md#get_characters_character_id_online) | **GET** /v2/characters/{character_id}/online/ | Get character online
*ESIClient::LocationApi* | [**get_characters_character_id_ship**](docs/LocationApi.md#get_characters_character_id_ship) | **GET** /v1/characters/{character_id}/ship/ | Get current ship
*ESIClient::LoyaltyApi* | [**get_characters_character_id_loyalty_points**](docs/LoyaltyApi.md#get_characters_character_id_loyalty_points) | **GET** /v1/characters/{character_id}/loyalty/points/ | Get loyalty points
*ESIClient::LoyaltyApi* | [**get_loyalty_stores_corporation_id_offers**](docs/LoyaltyApi.md#get_loyalty_stores_corporation_id_offers) | **GET** /v1/loyalty/stores/{corporation_id}/offers/ | List loyalty store offers
*ESIClient::MailApi* | [**delete_characters_character_id_mail_labels_label_id**](docs/MailApi.md#delete_characters_character_id_mail_labels_label_id) | **DELETE** /v1/characters/{character_id}/mail/labels/{label_id}/ | Delete a mail label
*ESIClient::MailApi* | [**delete_characters_character_id_mail_mail_id**](docs/MailApi.md#delete_characters_character_id_mail_mail_id) | **DELETE** /v1/characters/{character_id}/mail/{mail_id}/ | Delete a mail
*ESIClient::MailApi* | [**get_characters_character_id_mail**](docs/MailApi.md#get_characters_character_id_mail) | **GET** /v1/characters/{character_id}/mail/ | Return mail headers
*ESIClient::MailApi* | [**get_characters_character_id_mail_labels**](docs/MailApi.md#get_characters_character_id_mail_labels) | **GET** /v3/characters/{character_id}/mail/labels/ | Get mail labels and unread counts
*ESIClient::MailApi* | [**get_characters_character_id_mail_lists**](docs/MailApi.md#get_characters_character_id_mail_lists) | **GET** /v1/characters/{character_id}/mail/lists/ | Return mailing list subscriptions
*ESIClient::MailApi* | [**get_characters_character_id_mail_mail_id**](docs/MailApi.md#get_characters_character_id_mail_mail_id) | **GET** /v1/characters/{character_id}/mail/{mail_id}/ | Return a mail
*ESIClient::MailApi* | [**post_characters_character_id_mail**](docs/MailApi.md#post_characters_character_id_mail) | **POST** /v1/characters/{character_id}/mail/ | Send a new mail
*ESIClient::MailApi* | [**post_characters_character_id_mail_labels**](docs/MailApi.md#post_characters_character_id_mail_labels) | **POST** /v2/characters/{character_id}/mail/labels/ | Create a mail label
*ESIClient::MailApi* | [**put_characters_character_id_mail_mail_id**](docs/MailApi.md#put_characters_character_id_mail_mail_id) | **PUT** /v1/characters/{character_id}/mail/{mail_id}/ | Update metadata about a mail
*ESIClient::MarketApi* | [**get_characters_character_id_orders**](docs/MarketApi.md#get_characters_character_id_orders) | **GET** /v1/characters/{character_id}/orders/ | List open orders from a character
*ESIClient::MarketApi* | [**get_characters_character_id_orders_history**](docs/MarketApi.md#get_characters_character_id_orders_history) | **GET** /v1/characters/{character_id}/orders/history/ | List historical orders by a character
*ESIClient::MarketApi* | [**get_corporations_corporation_id_orders**](docs/MarketApi.md#get_corporations_corporation_id_orders) | **GET** /v1/corporations/{corporation_id}/orders/ | List open orders from a corporation
*ESIClient::MarketApi* | [**get_corporations_corporation_id_orders_history**](docs/MarketApi.md#get_corporations_corporation_id_orders_history) | **GET** /v1/corporations/{corporation_id}/orders/history/ | List historical orders from a corporation
*ESIClient::MarketApi* | [**get_markets_groups**](docs/MarketApi.md#get_markets_groups) | **GET** /v1/markets/groups/ | Get item groups
*ESIClient::MarketApi* | [**get_markets_groups_market_group_id**](docs/MarketApi.md#get_markets_groups_market_group_id) | **GET** /v1/markets/groups/{market_group_id}/ | Get item group information
*ESIClient::MarketApi* | [**get_markets_prices**](docs/MarketApi.md#get_markets_prices) | **GET** /v1/markets/prices/ | List market prices
*ESIClient::MarketApi* | [**get_markets_region_id_history**](docs/MarketApi.md#get_markets_region_id_history) | **GET** /v1/markets/{region_id}/history/ | List historical market statistics in a region
*ESIClient::MarketApi* | [**get_markets_region_id_orders**](docs/MarketApi.md#get_markets_region_id_orders) | **GET** /v1/markets/{region_id}/orders/ | List orders in a region
*ESIClient::MarketApi* | [**get_markets_region_id_types**](docs/MarketApi.md#get_markets_region_id_types) | **GET** /v1/markets/{region_id}/types/ | List type IDs relevant to a market
*ESIClient::MarketApi* | [**get_markets_structures_structure_id**](docs/MarketApi.md#get_markets_structures_structure_id) | **GET** /v1/markets/structures/{structure_id}/ | List orders in a structure
*ESIClient::OpportunitiesApi* | [**get_characters_character_id_opportunities**](docs/OpportunitiesApi.md#get_characters_character_id_opportunities) | **GET** /v1/characters/{character_id}/opportunities/ | Get a character's completed tasks
*ESIClient::OpportunitiesApi* | [**get_opportunities_groups**](docs/OpportunitiesApi.md#get_opportunities_groups) | **GET** /v1/opportunities/groups/ | Get opportunities groups
*ESIClient::OpportunitiesApi* | [**get_opportunities_groups_group_id**](docs/OpportunitiesApi.md#get_opportunities_groups_group_id) | **GET** /v1/opportunities/groups/{group_id}/ | Get opportunities group
*ESIClient::OpportunitiesApi* | [**get_opportunities_tasks**](docs/OpportunitiesApi.md#get_opportunities_tasks) | **GET** /v1/opportunities/tasks/ | Get opportunities tasks
*ESIClient::OpportunitiesApi* | [**get_opportunities_tasks_task_id**](docs/OpportunitiesApi.md#get_opportunities_tasks_task_id) | **GET** /v1/opportunities/tasks/{task_id}/ | Get opportunities task
*ESIClient::PlanetaryInteractionApi* | [**get_characters_character_id_planets**](docs/PlanetaryInteractionApi.md#get_characters_character_id_planets) | **GET** /v1/characters/{character_id}/planets/ | Get colonies
*ESIClient::PlanetaryInteractionApi* | [**get_characters_character_id_planets_planet_id**](docs/PlanetaryInteractionApi.md#get_characters_character_id_planets_planet_id) | **GET** /v3/characters/{character_id}/planets/{planet_id}/ | Get colony layout
*ESIClient::PlanetaryInteractionApi* | [**get_corporations_corporation_id_customs_offices**](docs/PlanetaryInteractionApi.md#get_corporations_corporation_id_customs_offices) | **GET** /v1/corporations/{corporation_id}/customs_offices/ | List corporation customs offices
*ESIClient::PlanetaryInteractionApi* | [**get_universe_schematics_schematic_id**](docs/PlanetaryInteractionApi.md#get_universe_schematics_schematic_id) | **GET** /v1/universe/schematics/{schematic_id}/ | Get schematic information
*ESIClient::RoutesApi* | [**get_route_origin_destination**](docs/RoutesApi.md#get_route_origin_destination) | **GET** /v1/route/{origin}/{destination}/ | Get route
*ESIClient::SearchApi* | [**get_characters_character_id_search**](docs/SearchApi.md#get_characters_character_id_search) | **GET** /v3/characters/{character_id}/search/ | Search on a string
*ESIClient::SearchApi* | [**get_search**](docs/SearchApi.md#get_search) | **GET** /v2/search/ | Search on a string
*ESIClient::SkillsApi* | [**get_characters_character_id_attributes**](docs/SkillsApi.md#get_characters_character_id_attributes) | **GET** /v1/characters/{character_id}/attributes/ | Get character attributes
*ESIClient::SkillsApi* | [**get_characters_character_id_skillqueue**](docs/SkillsApi.md#get_characters_character_id_skillqueue) | **GET** /v2/characters/{character_id}/skillqueue/ | Get character's skill queue
*ESIClient::SkillsApi* | [**get_characters_character_id_skills**](docs/SkillsApi.md#get_characters_character_id_skills) | **GET** /v4/characters/{character_id}/skills/ | Get character skills
*ESIClient::SovereigntyApi* | [**get_sovereignty_campaigns**](docs/SovereigntyApi.md#get_sovereignty_campaigns) | **GET** /v1/sovereignty/campaigns/ | List sovereignty campaigns
*ESIClient::SovereigntyApi* | [**get_sovereignty_map**](docs/SovereigntyApi.md#get_sovereignty_map) | **GET** /v1/sovereignty/map/ | List sovereignty of systems
*ESIClient::SovereigntyApi* | [**get_sovereignty_structures**](docs/SovereigntyApi.md#get_sovereignty_structures) | **GET** /v1/sovereignty/structures/ | List sovereignty structures
*ESIClient::StatusApi* | [**get_status**](docs/StatusApi.md#get_status) | **GET** /v1/status/ | Retrieve the uptime and player counts
*ESIClient::UniverseApi* | [**get_universe_ancestries**](docs/UniverseApi.md#get_universe_ancestries) | **GET** /v1/universe/ancestries/ | Get ancestries
*ESIClient::UniverseApi* | [**get_universe_bloodlines**](docs/UniverseApi.md#get_universe_bloodlines) | **GET** /v1/universe/bloodlines/ | Get bloodlines
*ESIClient::UniverseApi* | [**get_universe_categories**](docs/UniverseApi.md#get_universe_categories) | **GET** /v1/universe/categories/ | Get item categories
*ESIClient::UniverseApi* | [**get_universe_categories_category_id**](docs/UniverseApi.md#get_universe_categories_category_id) | **GET** /v1/universe/categories/{category_id}/ | Get item category information
*ESIClient::UniverseApi* | [**get_universe_constellations**](docs/UniverseApi.md#get_universe_constellations) | **GET** /v1/universe/constellations/ | Get constellations
*ESIClient::UniverseApi* | [**get_universe_constellations_constellation_id**](docs/UniverseApi.md#get_universe_constellations_constellation_id) | **GET** /v1/universe/constellations/{constellation_id}/ | Get constellation information
*ESIClient::UniverseApi* | [**get_universe_factions**](docs/UniverseApi.md#get_universe_factions) | **GET** /v2/universe/factions/ | Get factions
*ESIClient::UniverseApi* | [**get_universe_graphics**](docs/UniverseApi.md#get_universe_graphics) | **GET** /v1/universe/graphics/ | Get graphics
*ESIClient::UniverseApi* | [**get_universe_graphics_graphic_id**](docs/UniverseApi.md#get_universe_graphics_graphic_id) | **GET** /v1/universe/graphics/{graphic_id}/ | Get graphic information
*ESIClient::UniverseApi* | [**get_universe_groups**](docs/UniverseApi.md#get_universe_groups) | **GET** /v1/universe/groups/ | Get item groups
*ESIClient::UniverseApi* | [**get_universe_groups_group_id**](docs/UniverseApi.md#get_universe_groups_group_id) | **GET** /v1/universe/groups/{group_id}/ | Get item group information
*ESIClient::UniverseApi* | [**get_universe_moons_moon_id**](docs/UniverseApi.md#get_universe_moons_moon_id) | **GET** /v1/universe/moons/{moon_id}/ | Get moon information
*ESIClient::UniverseApi* | [**get_universe_planets_planet_id**](docs/UniverseApi.md#get_universe_planets_planet_id) | **GET** /v1/universe/planets/{planet_id}/ | Get planet information
*ESIClient::UniverseApi* | [**get_universe_races**](docs/UniverseApi.md#get_universe_races) | **GET** /v1/universe/races/ | Get character races
*ESIClient::UniverseApi* | [**get_universe_regions**](docs/UniverseApi.md#get_universe_regions) | **GET** /v1/universe/regions/ | Get regions
*ESIClient::UniverseApi* | [**get_universe_regions_region_id**](docs/UniverseApi.md#get_universe_regions_region_id) | **GET** /v1/universe/regions/{region_id}/ | Get region information
*ESIClient::UniverseApi* | [**get_universe_stargates_stargate_id**](docs/UniverseApi.md#get_universe_stargates_stargate_id) | **GET** /v1/universe/stargates/{stargate_id}/ | Get stargate information
*ESIClient::UniverseApi* | [**get_universe_stars_star_id**](docs/UniverseApi.md#get_universe_stars_star_id) | **GET** /v1/universe/stars/{star_id}/ | Get star information
*ESIClient::UniverseApi* | [**get_universe_stations_station_id**](docs/UniverseApi.md#get_universe_stations_station_id) | **GET** /v2/universe/stations/{station_id}/ | Get station information
*ESIClient::UniverseApi* | [**get_universe_structures**](docs/UniverseApi.md#get_universe_structures) | **GET** /v1/universe/structures/ | List all public structures
*ESIClient::UniverseApi* | [**get_universe_structures_structure_id**](docs/UniverseApi.md#get_universe_structures_structure_id) | **GET** /v1/universe/structures/{structure_id}/ | Get structure information
*ESIClient::UniverseApi* | [**get_universe_system_jumps**](docs/UniverseApi.md#get_universe_system_jumps) | **GET** /v1/universe/system_jumps/ | Get system jumps
*ESIClient::UniverseApi* | [**get_universe_system_kills**](docs/UniverseApi.md#get_universe_system_kills) | **GET** /v2/universe/system_kills/ | Get system kills
*ESIClient::UniverseApi* | [**get_universe_systems**](docs/UniverseApi.md#get_universe_systems) | **GET** /v1/universe/systems/ | Get solar systems
*ESIClient::UniverseApi* | [**get_universe_systems_system_id**](docs/UniverseApi.md#get_universe_systems_system_id) | **GET** /v3/universe/systems/{system_id}/ | Get solar system information
*ESIClient::UniverseApi* | [**get_universe_types**](docs/UniverseApi.md#get_universe_types) | **GET** /v1/universe/types/ | Get types
*ESIClient::UniverseApi* | [**get_universe_types_type_id**](docs/UniverseApi.md#get_universe_types_type_id) | **GET** /v3/universe/types/{type_id}/ | Get type information
*ESIClient::UniverseApi* | [**post_universe_ids**](docs/UniverseApi.md#post_universe_ids) | **POST** /v1/universe/ids/ | Bulk names to IDs
*ESIClient::UniverseApi* | [**post_universe_names**](docs/UniverseApi.md#post_universe_names) | **POST** /v2/universe/names/ | Get names and categories for a set of ID's
*ESIClient::UserInterfaceApi* | [**post_ui_autopilot_waypoint**](docs/UserInterfaceApi.md#post_ui_autopilot_waypoint) | **POST** /v2/ui/autopilot/waypoint/ | Set Autopilot Waypoint
*ESIClient::UserInterfaceApi* | [**post_ui_openwindow_contract**](docs/UserInterfaceApi.md#post_ui_openwindow_contract) | **POST** /v1/ui/openwindow/contract/ | Open Contract Window
*ESIClient::UserInterfaceApi* | [**post_ui_openwindow_information**](docs/UserInterfaceApi.md#post_ui_openwindow_information) | **POST** /v1/ui/openwindow/information/ | Open Information Window
*ESIClient::UserInterfaceApi* | [**post_ui_openwindow_marketdetails**](docs/UserInterfaceApi.md#post_ui_openwindow_marketdetails) | **POST** /v1/ui/openwindow/marketdetails/ | Open Market Details
*ESIClient::UserInterfaceApi* | [**post_ui_openwindow_newmail**](docs/UserInterfaceApi.md#post_ui_openwindow_newmail) | **POST** /v1/ui/openwindow/newmail/ | Open New Mail Window
*ESIClient::WalletApi* | [**get_characters_character_id_wallet**](docs/WalletApi.md#get_characters_character_id_wallet) | **GET** /v1/characters/{character_id}/wallet/ | Get a character's wallet balance
*ESIClient::WalletApi* | [**get_characters_character_id_wallet_journal**](docs/WalletApi.md#get_characters_character_id_wallet_journal) | **GET** /v3/characters/{character_id}/wallet/journal/ | Get character wallet journal
*ESIClient::WalletApi* | [**get_characters_character_id_wallet_transactions**](docs/WalletApi.md#get_characters_character_id_wallet_transactions) | **GET** /v1/characters/{character_id}/wallet/transactions/ | Get wallet transactions
*ESIClient::WalletApi* | [**get_corporations_corporation_id_wallets**](docs/WalletApi.md#get_corporations_corporation_id_wallets) | **GET** /v1/corporations/{corporation_id}/wallets/ | Returns a corporation's wallet balance
*ESIClient::WalletApi* | [**get_corporations_corporation_id_wallets_division_journal**](docs/WalletApi.md#get_corporations_corporation_id_wallets_division_journal) | **GET** /v2/corporations/{corporation_id}/wallets/{division}/journal/ | Get corporation wallet journal
*ESIClient::WalletApi* | [**get_corporations_corporation_id_wallets_division_transactions**](docs/WalletApi.md#get_corporations_corporation_id_wallets_division_transactions) | **GET** /v1/corporations/{corporation_id}/wallets/{division}/transactions/ | Get corporation wallet transactions
*ESIClient::WarsApi* | [**get_wars**](docs/WarsApi.md#get_wars) | **GET** /v1/wars/ | List wars
*ESIClient::WarsApi* | [**get_wars_war_id**](docs/WarsApi.md#get_wars_war_id) | **GET** /v1/wars/{war_id}/ | Get war information
*ESIClient::WarsApi* | [**get_wars_war_id_killmails**](docs/WarsApi.md#get_wars_war_id_killmails) | **GET** /v1/wars/{war_id}/killmails/ | List kills for a war


## Documentation for Models

 - [ESIClient::DeleteCharactersCharacterIdMailLabelsLabelIdUnprocessableEntity](docs/DeleteCharactersCharacterIdMailLabelsLabelIdUnprocessableEntity.md)
 - [ESIClient::DeleteFleetsFleetIdMembersMemberIdNotFound](docs/DeleteFleetsFleetIdMembersMemberIdNotFound.md)
 - [ESIClient::DeleteFleetsFleetIdSquadsSquadIdNotFound](docs/DeleteFleetsFleetIdSquadsSquadIdNotFound.md)
 - [ESIClient::DeleteFleetsFleetIdWingsWingIdNotFound](docs/DeleteFleetsFleetIdWingsWingIdNotFound.md)
 - [ESIClient::Forbidden](docs/Forbidden.md)
 - [ESIClient::GetAlliancesAllianceIdContacts200Ok](docs/GetAlliancesAllianceIdContacts200Ok.md)
 - [ESIClient::GetAlliancesAllianceIdIconsNotFound](docs/GetAlliancesAllianceIdIconsNotFound.md)
 - [ESIClient::GetAlliancesAllianceIdIconsOk](docs/GetAlliancesAllianceIdIconsOk.md)
 - [ESIClient::GetAlliancesAllianceIdNotFound](docs/GetAlliancesAllianceIdNotFound.md)
 - [ESIClient::GetAlliancesAllianceIdOk](docs/GetAlliancesAllianceIdOk.md)
 - [ESIClient::GetAlliancesNames200Ok](docs/GetAlliancesNames200Ok.md)
 - [ESIClient::GetCharactersCharacterIdAgentsResearch200Ok](docs/GetCharactersCharacterIdAgentsResearch200Ok.md)
 - [ESIClient::GetCharactersCharacterIdAssets200Ok](docs/GetCharactersCharacterIdAssets200Ok.md)
 - [ESIClient::GetCharactersCharacterIdAttributesOk](docs/GetCharactersCharacterIdAttributesOk.md)
 - [ESIClient::GetCharactersCharacterIdBlueprints200Ok](docs/GetCharactersCharacterIdBlueprints200Ok.md)
 - [ESIClient::GetCharactersCharacterIdBookmarks200Ok](docs/GetCharactersCharacterIdBookmarks200Ok.md)
 - [ESIClient::GetCharactersCharacterIdBookmarksCoordinates](docs/GetCharactersCharacterIdBookmarksCoordinates.md)
 - [ESIClient::GetCharactersCharacterIdBookmarksFolders200Ok](docs/GetCharactersCharacterIdBookmarksFolders200Ok.md)
 - [ESIClient::GetCharactersCharacterIdBookmarksItem](docs/GetCharactersCharacterIdBookmarksItem.md)
 - [ESIClient::GetCharactersCharacterIdCalendar200Ok](docs/GetCharactersCharacterIdCalendar200Ok.md)
 - [ESIClient::GetCharactersCharacterIdCalendarEventIdAttendees200Ok](docs/GetCharactersCharacterIdCalendarEventIdAttendees200Ok.md)
 - [ESIClient::GetCharactersCharacterIdCalendarEventIdOk](docs/GetCharactersCharacterIdCalendarEventIdOk.md)
 - [ESIClient::GetCharactersCharacterIdChatChannels200Ok](docs/GetCharactersCharacterIdChatChannels200Ok.md)
 - [ESIClient::GetCharactersCharacterIdChatChannelsAllowed](docs/GetCharactersCharacterIdChatChannelsAllowed.md)
 - [ESIClient::GetCharactersCharacterIdChatChannelsBlocked](docs/GetCharactersCharacterIdChatChannelsBlocked.md)
 - [ESIClient::GetCharactersCharacterIdChatChannelsMuted](docs/GetCharactersCharacterIdChatChannelsMuted.md)
 - [ESIClient::GetCharactersCharacterIdChatChannelsOperator](docs/GetCharactersCharacterIdChatChannelsOperator.md)
 - [ESIClient::GetCharactersCharacterIdClonesHomeLocation](docs/GetCharactersCharacterIdClonesHomeLocation.md)
 - [ESIClient::GetCharactersCharacterIdClonesJumpClone](docs/GetCharactersCharacterIdClonesJumpClone.md)
 - [ESIClient::GetCharactersCharacterIdClonesOk](docs/GetCharactersCharacterIdClonesOk.md)
 - [ESIClient::GetCharactersCharacterIdContacts200Ok](docs/GetCharactersCharacterIdContacts200Ok.md)
 - [ESIClient::GetCharactersCharacterIdContactsLabels200Ok](docs/GetCharactersCharacterIdContactsLabels200Ok.md)
 - [ESIClient::GetCharactersCharacterIdContracts200Ok](docs/GetCharactersCharacterIdContracts200Ok.md)
 - [ESIClient::GetCharactersCharacterIdContractsContractIdBids200Ok](docs/GetCharactersCharacterIdContractsContractIdBids200Ok.md)
 - [ESIClient::GetCharactersCharacterIdContractsContractIdItems200Ok](docs/GetCharactersCharacterIdContractsContractIdItems200Ok.md)
 - [ESIClient::GetCharactersCharacterIdCorporationhistory200Ok](docs/GetCharactersCharacterIdCorporationhistory200Ok.md)
 - [ESIClient::GetCharactersCharacterIdFatigueOk](docs/GetCharactersCharacterIdFatigueOk.md)
 - [ESIClient::GetCharactersCharacterIdFittings200Ok](docs/GetCharactersCharacterIdFittings200Ok.md)
 - [ESIClient::GetCharactersCharacterIdFittingsItem](docs/GetCharactersCharacterIdFittingsItem.md)
 - [ESIClient::GetCharactersCharacterIdFleetNotFound](docs/GetCharactersCharacterIdFleetNotFound.md)
 - [ESIClient::GetCharactersCharacterIdFleetOk](docs/GetCharactersCharacterIdFleetOk.md)
 - [ESIClient::GetCharactersCharacterIdFwStatsKills](docs/GetCharactersCharacterIdFwStatsKills.md)
 - [ESIClient::GetCharactersCharacterIdFwStatsOk](docs/GetCharactersCharacterIdFwStatsOk.md)
 - [ESIClient::GetCharactersCharacterIdFwStatsVictoryPoints](docs/GetCharactersCharacterIdFwStatsVictoryPoints.md)
 - [ESIClient::GetCharactersCharacterIdIndustryJobs200Ok](docs/GetCharactersCharacterIdIndustryJobs200Ok.md)
 - [ESIClient::GetCharactersCharacterIdKillmailsRecent200Ok](docs/GetCharactersCharacterIdKillmailsRecent200Ok.md)
 - [ESIClient::GetCharactersCharacterIdLocationOk](docs/GetCharactersCharacterIdLocationOk.md)
 - [ESIClient::GetCharactersCharacterIdLoyaltyPoints200Ok](docs/GetCharactersCharacterIdLoyaltyPoints200Ok.md)
 - [ESIClient::GetCharactersCharacterIdMail200Ok](docs/GetCharactersCharacterIdMail200Ok.md)
 - [ESIClient::GetCharactersCharacterIdMailLabelsLabel](docs/GetCharactersCharacterIdMailLabelsLabel.md)
 - [ESIClient::GetCharactersCharacterIdMailLabelsOk](docs/GetCharactersCharacterIdMailLabelsOk.md)
 - [ESIClient::GetCharactersCharacterIdMailLists200Ok](docs/GetCharactersCharacterIdMailLists200Ok.md)
 - [ESIClient::GetCharactersCharacterIdMailMailIdNotFound](docs/GetCharactersCharacterIdMailMailIdNotFound.md)
 - [ESIClient::GetCharactersCharacterIdMailMailIdOk](docs/GetCharactersCharacterIdMailMailIdOk.md)
 - [ESIClient::GetCharactersCharacterIdMailMailIdRecipient](docs/GetCharactersCharacterIdMailMailIdRecipient.md)
 - [ESIClient::GetCharactersCharacterIdMailRecipient](docs/GetCharactersCharacterIdMailRecipient.md)
 - [ESIClient::GetCharactersCharacterIdMedals200Ok](docs/GetCharactersCharacterIdMedals200Ok.md)
 - [ESIClient::GetCharactersCharacterIdMedalsGraphic](docs/GetCharactersCharacterIdMedalsGraphic.md)
 - [ESIClient::GetCharactersCharacterIdMining200Ok](docs/GetCharactersCharacterIdMining200Ok.md)
 - [ESIClient::GetCharactersCharacterIdNotFound](docs/GetCharactersCharacterIdNotFound.md)
 - [ESIClient::GetCharactersCharacterIdNotifications200Ok](docs/GetCharactersCharacterIdNotifications200Ok.md)
 - [ESIClient::GetCharactersCharacterIdNotificationsContacts200Ok](docs/GetCharactersCharacterIdNotificationsContacts200Ok.md)
 - [ESIClient::GetCharactersCharacterIdOk](docs/GetCharactersCharacterIdOk.md)
 - [ESIClient::GetCharactersCharacterIdOnlineOk](docs/GetCharactersCharacterIdOnlineOk.md)
 - [ESIClient::GetCharactersCharacterIdOpportunities200Ok](docs/GetCharactersCharacterIdOpportunities200Ok.md)
 - [ESIClient::GetCharactersCharacterIdOrders200Ok](docs/GetCharactersCharacterIdOrders200Ok.md)
 - [ESIClient::GetCharactersCharacterIdOrdersHistory200Ok](docs/GetCharactersCharacterIdOrdersHistory200Ok.md)
 - [ESIClient::GetCharactersCharacterIdPlanets200Ok](docs/GetCharactersCharacterIdPlanets200Ok.md)
 - [ESIClient::GetCharactersCharacterIdPlanetsPlanetIdContent](docs/GetCharactersCharacterIdPlanetsPlanetIdContent.md)
 - [ESIClient::GetCharactersCharacterIdPlanetsPlanetIdExtractorDetails](docs/GetCharactersCharacterIdPlanetsPlanetIdExtractorDetails.md)
 - [ESIClient::GetCharactersCharacterIdPlanetsPlanetIdFactoryDetails](docs/GetCharactersCharacterIdPlanetsPlanetIdFactoryDetails.md)
 - [ESIClient::GetCharactersCharacterIdPlanetsPlanetIdHead](docs/GetCharactersCharacterIdPlanetsPlanetIdHead.md)
 - [ESIClient::GetCharactersCharacterIdPlanetsPlanetIdLink](docs/GetCharactersCharacterIdPlanetsPlanetIdLink.md)
 - [ESIClient::GetCharactersCharacterIdPlanetsPlanetIdNotFound](docs/GetCharactersCharacterIdPlanetsPlanetIdNotFound.md)
 - [ESIClient::GetCharactersCharacterIdPlanetsPlanetIdOk](docs/GetCharactersCharacterIdPlanetsPlanetIdOk.md)
 - [ESIClient::GetCharactersCharacterIdPlanetsPlanetIdPin](docs/GetCharactersCharacterIdPlanetsPlanetIdPin.md)
 - [ESIClient::GetCharactersCharacterIdPlanetsPlanetIdRoute](docs/GetCharactersCharacterIdPlanetsPlanetIdRoute.md)
 - [ESIClient::GetCharactersCharacterIdPortraitNotFound](docs/GetCharactersCharacterIdPortraitNotFound.md)
 - [ESIClient::GetCharactersCharacterIdPortraitOk](docs/GetCharactersCharacterIdPortraitOk.md)
 - [ESIClient::GetCharactersCharacterIdRolesOk](docs/GetCharactersCharacterIdRolesOk.md)
 - [ESIClient::GetCharactersCharacterIdSearchOk](docs/GetCharactersCharacterIdSearchOk.md)
 - [ESIClient::GetCharactersCharacterIdShipOk](docs/GetCharactersCharacterIdShipOk.md)
 - [ESIClient::GetCharactersCharacterIdSkillqueue200Ok](docs/GetCharactersCharacterIdSkillqueue200Ok.md)
 - [ESIClient::GetCharactersCharacterIdSkillsOk](docs/GetCharactersCharacterIdSkillsOk.md)
 - [ESIClient::GetCharactersCharacterIdSkillsSkill](docs/GetCharactersCharacterIdSkillsSkill.md)
 - [ESIClient::GetCharactersCharacterIdStandings200Ok](docs/GetCharactersCharacterIdStandings200Ok.md)
 - [ESIClient::GetCharactersCharacterIdStats200Ok](docs/GetCharactersCharacterIdStats200Ok.md)
 - [ESIClient::GetCharactersCharacterIdStatsCharacter](docs/GetCharactersCharacterIdStatsCharacter.md)
 - [ESIClient::GetCharactersCharacterIdStatsCombat](docs/GetCharactersCharacterIdStatsCombat.md)
 - [ESIClient::GetCharactersCharacterIdStatsIndustry](docs/GetCharactersCharacterIdStatsIndustry.md)
 - [ESIClient::GetCharactersCharacterIdStatsInventory](docs/GetCharactersCharacterIdStatsInventory.md)
 - [ESIClient::GetCharactersCharacterIdStatsIsk](docs/GetCharactersCharacterIdStatsIsk.md)
 - [ESIClient::GetCharactersCharacterIdStatsMarket](docs/GetCharactersCharacterIdStatsMarket.md)
 - [ESIClient::GetCharactersCharacterIdStatsMining](docs/GetCharactersCharacterIdStatsMining.md)
 - [ESIClient::GetCharactersCharacterIdStatsModule](docs/GetCharactersCharacterIdStatsModule.md)
 - [ESIClient::GetCharactersCharacterIdStatsOrbital](docs/GetCharactersCharacterIdStatsOrbital.md)
 - [ESIClient::GetCharactersCharacterIdStatsPve](docs/GetCharactersCharacterIdStatsPve.md)
 - [ESIClient::GetCharactersCharacterIdStatsSocial](docs/GetCharactersCharacterIdStatsSocial.md)
 - [ESIClient::GetCharactersCharacterIdStatsTravel](docs/GetCharactersCharacterIdStatsTravel.md)
 - [ESIClient::GetCharactersCharacterIdTitles200Ok](docs/GetCharactersCharacterIdTitles200Ok.md)
 - [ESIClient::GetCharactersCharacterIdWalletJournal200Ok](docs/GetCharactersCharacterIdWalletJournal200Ok.md)
 - [ESIClient::GetCharactersCharacterIdWalletJournalExtraInfo](docs/GetCharactersCharacterIdWalletJournalExtraInfo.md)
 - [ESIClient::GetCharactersCharacterIdWalletTransactions200Ok](docs/GetCharactersCharacterIdWalletTransactions200Ok.md)
 - [ESIClient::GetCharactersNames200Ok](docs/GetCharactersNames200Ok.md)
 - [ESIClient::GetCorporationCorporationIdMiningExtractions200Ok](docs/GetCorporationCorporationIdMiningExtractions200Ok.md)
 - [ESIClient::GetCorporationCorporationIdMiningObservers200Ok](docs/GetCorporationCorporationIdMiningObservers200Ok.md)
 - [ESIClient::GetCorporationCorporationIdMiningObserversObserverId200Ok](docs/GetCorporationCorporationIdMiningObserversObserverId200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdAlliancehistory200Ok](docs/GetCorporationsCorporationIdAlliancehistory200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdAssets200Ok](docs/GetCorporationsCorporationIdAssets200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdBlueprints200Ok](docs/GetCorporationsCorporationIdBlueprints200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdBookmarks200Ok](docs/GetCorporationsCorporationIdBookmarks200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdBookmarksCoordinates](docs/GetCorporationsCorporationIdBookmarksCoordinates.md)
 - [ESIClient::GetCorporationsCorporationIdBookmarksFolders200Ok](docs/GetCorporationsCorporationIdBookmarksFolders200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdBookmarksItem](docs/GetCorporationsCorporationIdBookmarksItem.md)
 - [ESIClient::GetCorporationsCorporationIdContacts200Ok](docs/GetCorporationsCorporationIdContacts200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdContainersLogs200Ok](docs/GetCorporationsCorporationIdContainersLogs200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdContracts200Ok](docs/GetCorporationsCorporationIdContracts200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdContractsContractIdBids200Ok](docs/GetCorporationsCorporationIdContractsContractIdBids200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdContractsContractIdItems200Ok](docs/GetCorporationsCorporationIdContractsContractIdItems200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdCustomsOffices200Ok](docs/GetCorporationsCorporationIdCustomsOffices200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdDivisionsHangar](docs/GetCorporationsCorporationIdDivisionsHangar.md)
 - [ESIClient::GetCorporationsCorporationIdDivisionsOk](docs/GetCorporationsCorporationIdDivisionsOk.md)
 - [ESIClient::GetCorporationsCorporationIdDivisionsWallet](docs/GetCorporationsCorporationIdDivisionsWallet.md)
 - [ESIClient::GetCorporationsCorporationIdFacilities200Ok](docs/GetCorporationsCorporationIdFacilities200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdFwStatsKills](docs/GetCorporationsCorporationIdFwStatsKills.md)
 - [ESIClient::GetCorporationsCorporationIdFwStatsOk](docs/GetCorporationsCorporationIdFwStatsOk.md)
 - [ESIClient::GetCorporationsCorporationIdFwStatsVictoryPoints](docs/GetCorporationsCorporationIdFwStatsVictoryPoints.md)
 - [ESIClient::GetCorporationsCorporationIdIconsNotFound](docs/GetCorporationsCorporationIdIconsNotFound.md)
 - [ESIClient::GetCorporationsCorporationIdIconsOk](docs/GetCorporationsCorporationIdIconsOk.md)
 - [ESIClient::GetCorporationsCorporationIdIndustryJobs200Ok](docs/GetCorporationsCorporationIdIndustryJobs200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdKillmailsRecent200Ok](docs/GetCorporationsCorporationIdKillmailsRecent200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdMedals200Ok](docs/GetCorporationsCorporationIdMedals200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdMedalsIssued200Ok](docs/GetCorporationsCorporationIdMedalsIssued200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdMembersTitles200Ok](docs/GetCorporationsCorporationIdMembersTitles200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdMembertracking200Ok](docs/GetCorporationsCorporationIdMembertracking200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdNotFound](docs/GetCorporationsCorporationIdNotFound.md)
 - [ESIClient::GetCorporationsCorporationIdOk](docs/GetCorporationsCorporationIdOk.md)
 - [ESIClient::GetCorporationsCorporationIdOrders200Ok](docs/GetCorporationsCorporationIdOrders200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdOrdersHistory200Ok](docs/GetCorporationsCorporationIdOrdersHistory200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdOutpostsOutpostIdCoordinates](docs/GetCorporationsCorporationIdOutpostsOutpostIdCoordinates.md)
 - [ESIClient::GetCorporationsCorporationIdOutpostsOutpostIdOk](docs/GetCorporationsCorporationIdOutpostsOutpostIdOk.md)
 - [ESIClient::GetCorporationsCorporationIdOutpostsOutpostIdService](docs/GetCorporationsCorporationIdOutpostsOutpostIdService.md)
 - [ESIClient::GetCorporationsCorporationIdRoles200Ok](docs/GetCorporationsCorporationIdRoles200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdRolesHistory200Ok](docs/GetCorporationsCorporationIdRolesHistory200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdShareholders200Ok](docs/GetCorporationsCorporationIdShareholders200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdStandings200Ok](docs/GetCorporationsCorporationIdStandings200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdStarbases200Ok](docs/GetCorporationsCorporationIdStarbases200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdStarbasesStarbaseIdFuel](docs/GetCorporationsCorporationIdStarbasesStarbaseIdFuel.md)
 - [ESIClient::GetCorporationsCorporationIdStarbasesStarbaseIdOk](docs/GetCorporationsCorporationIdStarbasesStarbaseIdOk.md)
 - [ESIClient::GetCorporationsCorporationIdStructures200Ok](docs/GetCorporationsCorporationIdStructures200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdStructuresService](docs/GetCorporationsCorporationIdStructuresService.md)
 - [ESIClient::GetCorporationsCorporationIdTitles200Ok](docs/GetCorporationsCorporationIdTitles200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdWallets200Ok](docs/GetCorporationsCorporationIdWallets200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdWalletsDivisionJournal200Ok](docs/GetCorporationsCorporationIdWalletsDivisionJournal200Ok.md)
 - [ESIClient::GetCorporationsCorporationIdWalletsDivisionJournalExtraInfo](docs/GetCorporationsCorporationIdWalletsDivisionJournalExtraInfo.md)
 - [ESIClient::GetCorporationsCorporationIdWalletsDivisionTransactions200Ok](docs/GetCorporationsCorporationIdWalletsDivisionTransactions200Ok.md)
 - [ESIClient::GetCorporationsNames200Ok](docs/GetCorporationsNames200Ok.md)
 - [ESIClient::GetDogmaAttributesAttributeIdNotFound](docs/GetDogmaAttributesAttributeIdNotFound.md)
 - [ESIClient::GetDogmaAttributesAttributeIdOk](docs/GetDogmaAttributesAttributeIdOk.md)
 - [ESIClient::GetDogmaEffectsEffectIdModifier](docs/GetDogmaEffectsEffectIdModifier.md)
 - [ESIClient::GetDogmaEffectsEffectIdNotFound](docs/GetDogmaEffectsEffectIdNotFound.md)
 - [ESIClient::GetDogmaEffectsEffectIdOk](docs/GetDogmaEffectsEffectIdOk.md)
 - [ESIClient::GetFleetsFleetIdMembers200Ok](docs/GetFleetsFleetIdMembers200Ok.md)
 - [ESIClient::GetFleetsFleetIdMembersNotFound](docs/GetFleetsFleetIdMembersNotFound.md)
 - [ESIClient::GetFleetsFleetIdNotFound](docs/GetFleetsFleetIdNotFound.md)
 - [ESIClient::GetFleetsFleetIdOk](docs/GetFleetsFleetIdOk.md)
 - [ESIClient::GetFleetsFleetIdWings200Ok](docs/GetFleetsFleetIdWings200Ok.md)
 - [ESIClient::GetFleetsFleetIdWingsNotFound](docs/GetFleetsFleetIdWingsNotFound.md)
 - [ESIClient::GetFleetsFleetIdWingsSquad](docs/GetFleetsFleetIdWingsSquad.md)
 - [ESIClient::GetFwLeaderboardsActiveTotal](docs/GetFwLeaderboardsActiveTotal.md)
 - [ESIClient::GetFwLeaderboardsActiveTotal1](docs/GetFwLeaderboardsActiveTotal1.md)
 - [ESIClient::GetFwLeaderboardsCharactersActiveTotal](docs/GetFwLeaderboardsCharactersActiveTotal.md)
 - [ESIClient::GetFwLeaderboardsCharactersActiveTotal1](docs/GetFwLeaderboardsCharactersActiveTotal1.md)
 - [ESIClient::GetFwLeaderboardsCharactersKills](docs/GetFwLeaderboardsCharactersKills.md)
 - [ESIClient::GetFwLeaderboardsCharactersLastWeek](docs/GetFwLeaderboardsCharactersLastWeek.md)
 - [ESIClient::GetFwLeaderboardsCharactersLastWeek1](docs/GetFwLeaderboardsCharactersLastWeek1.md)
 - [ESIClient::GetFwLeaderboardsCharactersOk](docs/GetFwLeaderboardsCharactersOk.md)
 - [ESIClient::GetFwLeaderboardsCharactersVictoryPoints](docs/GetFwLeaderboardsCharactersVictoryPoints.md)
 - [ESIClient::GetFwLeaderboardsCharactersYesterday](docs/GetFwLeaderboardsCharactersYesterday.md)
 - [ESIClient::GetFwLeaderboardsCharactersYesterday1](docs/GetFwLeaderboardsCharactersYesterday1.md)
 - [ESIClient::GetFwLeaderboardsCorporationsActiveTotal](docs/GetFwLeaderboardsCorporationsActiveTotal.md)
 - [ESIClient::GetFwLeaderboardsCorporationsActiveTotal1](docs/GetFwLeaderboardsCorporationsActiveTotal1.md)
 - [ESIClient::GetFwLeaderboardsCorporationsKills](docs/GetFwLeaderboardsCorporationsKills.md)
 - [ESIClient::GetFwLeaderboardsCorporationsLastWeek](docs/GetFwLeaderboardsCorporationsLastWeek.md)
 - [ESIClient::GetFwLeaderboardsCorporationsLastWeek1](docs/GetFwLeaderboardsCorporationsLastWeek1.md)
 - [ESIClient::GetFwLeaderboardsCorporationsOk](docs/GetFwLeaderboardsCorporationsOk.md)
 - [ESIClient::GetFwLeaderboardsCorporationsVictoryPoints](docs/GetFwLeaderboardsCorporationsVictoryPoints.md)
 - [ESIClient::GetFwLeaderboardsCorporationsYesterday](docs/GetFwLeaderboardsCorporationsYesterday.md)
 - [ESIClient::GetFwLeaderboardsCorporationsYesterday1](docs/GetFwLeaderboardsCorporationsYesterday1.md)
 - [ESIClient::GetFwLeaderboardsKills](docs/GetFwLeaderboardsKills.md)
 - [ESIClient::GetFwLeaderboardsLastWeek](docs/GetFwLeaderboardsLastWeek.md)
 - [ESIClient::GetFwLeaderboardsLastWeek1](docs/GetFwLeaderboardsLastWeek1.md)
 - [ESIClient::GetFwLeaderboardsOk](docs/GetFwLeaderboardsOk.md)
 - [ESIClient::GetFwLeaderboardsVictoryPoints](docs/GetFwLeaderboardsVictoryPoints.md)
 - [ESIClient::GetFwLeaderboardsYesterday](docs/GetFwLeaderboardsYesterday.md)
 - [ESIClient::GetFwLeaderboardsYesterday1](docs/GetFwLeaderboardsYesterday1.md)
 - [ESIClient::GetFwStats200Ok](docs/GetFwStats200Ok.md)
 - [ESIClient::GetFwStatsKills](docs/GetFwStatsKills.md)
 - [ESIClient::GetFwStatsVictoryPoints](docs/GetFwStatsVictoryPoints.md)
 - [ESIClient::GetFwSystems200Ok](docs/GetFwSystems200Ok.md)
 - [ESIClient::GetFwWars200Ok](docs/GetFwWars200Ok.md)
 - [ESIClient::GetIncursions200Ok](docs/GetIncursions200Ok.md)
 - [ESIClient::GetIndustryFacilities200Ok](docs/GetIndustryFacilities200Ok.md)
 - [ESIClient::GetIndustrySystems200Ok](docs/GetIndustrySystems200Ok.md)
 - [ESIClient::GetIndustrySystemsCostIndice](docs/GetIndustrySystemsCostIndice.md)
 - [ESIClient::GetInsurancePrices200Ok](docs/GetInsurancePrices200Ok.md)
 - [ESIClient::GetInsurancePricesLevel](docs/GetInsurancePricesLevel.md)
 - [ESIClient::GetKillmailsKillmailIdKillmailHashAttacker](docs/GetKillmailsKillmailIdKillmailHashAttacker.md)
 - [ESIClient::GetKillmailsKillmailIdKillmailHashItem](docs/GetKillmailsKillmailIdKillmailHashItem.md)
 - [ESIClient::GetKillmailsKillmailIdKillmailHashItem1](docs/GetKillmailsKillmailIdKillmailHashItem1.md)
 - [ESIClient::GetKillmailsKillmailIdKillmailHashOk](docs/GetKillmailsKillmailIdKillmailHashOk.md)
 - [ESIClient::GetKillmailsKillmailIdKillmailHashPosition](docs/GetKillmailsKillmailIdKillmailHashPosition.md)
 - [ESIClient::GetKillmailsKillmailIdKillmailHashUnprocessableEntity](docs/GetKillmailsKillmailIdKillmailHashUnprocessableEntity.md)
 - [ESIClient::GetKillmailsKillmailIdKillmailHashVictim](docs/GetKillmailsKillmailIdKillmailHashVictim.md)
 - [ESIClient::GetLoyaltyStoresCorporationIdOffers200Ok](docs/GetLoyaltyStoresCorporationIdOffers200Ok.md)
 - [ESIClient::GetLoyaltyStoresCorporationIdOffersNotFound](docs/GetLoyaltyStoresCorporationIdOffersNotFound.md)
 - [ESIClient::GetLoyaltyStoresCorporationIdOffersRequiredItem](docs/GetLoyaltyStoresCorporationIdOffersRequiredItem.md)
 - [ESIClient::GetMarketsGroupsMarketGroupIdNotFound](docs/GetMarketsGroupsMarketGroupIdNotFound.md)
 - [ESIClient::GetMarketsGroupsMarketGroupIdOk](docs/GetMarketsGroupsMarketGroupIdOk.md)
 - [ESIClient::GetMarketsPrices200Ok](docs/GetMarketsPrices200Ok.md)
 - [ESIClient::GetMarketsRegionIdHistory200Ok](docs/GetMarketsRegionIdHistory200Ok.md)
 - [ESIClient::GetMarketsRegionIdHistoryUnprocessableEntity](docs/GetMarketsRegionIdHistoryUnprocessableEntity.md)
 - [ESIClient::GetMarketsRegionIdOrders200Ok](docs/GetMarketsRegionIdOrders200Ok.md)
 - [ESIClient::GetMarketsRegionIdOrdersUnprocessableEntity](docs/GetMarketsRegionIdOrdersUnprocessableEntity.md)
 - [ESIClient::GetMarketsStructuresStructureId200Ok](docs/GetMarketsStructuresStructureId200Ok.md)
 - [ESIClient::GetOpportunitiesGroupsGroupIdOk](docs/GetOpportunitiesGroupsGroupIdOk.md)
 - [ESIClient::GetOpportunitiesTasksTaskIdOk](docs/GetOpportunitiesTasksTaskIdOk.md)
 - [ESIClient::GetRouteOriginDestinationNotFound](docs/GetRouteOriginDestinationNotFound.md)
 - [ESIClient::GetSearchOk](docs/GetSearchOk.md)
 - [ESIClient::GetSovereigntyCampaigns200Ok](docs/GetSovereigntyCampaigns200Ok.md)
 - [ESIClient::GetSovereigntyCampaignsParticipant](docs/GetSovereigntyCampaignsParticipant.md)
 - [ESIClient::GetSovereigntyMap200Ok](docs/GetSovereigntyMap200Ok.md)
 - [ESIClient::GetSovereigntyStructures200Ok](docs/GetSovereigntyStructures200Ok.md)
 - [ESIClient::GetStatusOk](docs/GetStatusOk.md)
 - [ESIClient::GetUniverseAncestries200Ok](docs/GetUniverseAncestries200Ok.md)
 - [ESIClient::GetUniverseBloodlines200Ok](docs/GetUniverseBloodlines200Ok.md)
 - [ESIClient::GetUniverseCategoriesCategoryIdNotFound](docs/GetUniverseCategoriesCategoryIdNotFound.md)
 - [ESIClient::GetUniverseCategoriesCategoryIdOk](docs/GetUniverseCategoriesCategoryIdOk.md)
 - [ESIClient::GetUniverseConstellationsConstellationIdNotFound](docs/GetUniverseConstellationsConstellationIdNotFound.md)
 - [ESIClient::GetUniverseConstellationsConstellationIdOk](docs/GetUniverseConstellationsConstellationIdOk.md)
 - [ESIClient::GetUniverseConstellationsConstellationIdPosition](docs/GetUniverseConstellationsConstellationIdPosition.md)
 - [ESIClient::GetUniverseFactions200Ok](docs/GetUniverseFactions200Ok.md)
 - [ESIClient::GetUniverseGraphicsGraphicIdNotFound](docs/GetUniverseGraphicsGraphicIdNotFound.md)
 - [ESIClient::GetUniverseGraphicsGraphicIdOk](docs/GetUniverseGraphicsGraphicIdOk.md)
 - [ESIClient::GetUniverseGroupsGroupIdNotFound](docs/GetUniverseGroupsGroupIdNotFound.md)
 - [ESIClient::GetUniverseGroupsGroupIdOk](docs/GetUniverseGroupsGroupIdOk.md)
 - [ESIClient::GetUniverseMoonsMoonIdNotFound](docs/GetUniverseMoonsMoonIdNotFound.md)
 - [ESIClient::GetUniverseMoonsMoonIdOk](docs/GetUniverseMoonsMoonIdOk.md)
 - [ESIClient::GetUniverseMoonsMoonIdPosition](docs/GetUniverseMoonsMoonIdPosition.md)
 - [ESIClient::GetUniversePlanetsPlanetIdNotFound](docs/GetUniversePlanetsPlanetIdNotFound.md)
 - [ESIClient::GetUniversePlanetsPlanetIdOk](docs/GetUniversePlanetsPlanetIdOk.md)
 - [ESIClient::GetUniversePlanetsPlanetIdPosition](docs/GetUniversePlanetsPlanetIdPosition.md)
 - [ESIClient::GetUniverseRaces200Ok](docs/GetUniverseRaces200Ok.md)
 - [ESIClient::GetUniverseRegionsRegionIdNotFound](docs/GetUniverseRegionsRegionIdNotFound.md)
 - [ESIClient::GetUniverseRegionsRegionIdOk](docs/GetUniverseRegionsRegionIdOk.md)
 - [ESIClient::GetUniverseSchematicsSchematicIdNotFound](docs/GetUniverseSchematicsSchematicIdNotFound.md)
 - [ESIClient::GetUniverseSchematicsSchematicIdOk](docs/GetUniverseSchematicsSchematicIdOk.md)
 - [ESIClient::GetUniverseStargatesStargateIdDestination](docs/GetUniverseStargatesStargateIdDestination.md)
 - [ESIClient::GetUniverseStargatesStargateIdNotFound](docs/GetUniverseStargatesStargateIdNotFound.md)
 - [ESIClient::GetUniverseStargatesStargateIdOk](docs/GetUniverseStargatesStargateIdOk.md)
 - [ESIClient::GetUniverseStargatesStargateIdPosition](docs/GetUniverseStargatesStargateIdPosition.md)
 - [ESIClient::GetUniverseStarsStarIdOk](docs/GetUniverseStarsStarIdOk.md)
 - [ESIClient::GetUniverseStationsStationIdNotFound](docs/GetUniverseStationsStationIdNotFound.md)
 - [ESIClient::GetUniverseStationsStationIdOk](docs/GetUniverseStationsStationIdOk.md)
 - [ESIClient::GetUniverseStationsStationIdPosition](docs/GetUniverseStationsStationIdPosition.md)
 - [ESIClient::GetUniverseStructuresStructureIdNotFound](docs/GetUniverseStructuresStructureIdNotFound.md)
 - [ESIClient::GetUniverseStructuresStructureIdOk](docs/GetUniverseStructuresStructureIdOk.md)
 - [ESIClient::GetUniverseStructuresStructureIdPosition](docs/GetUniverseStructuresStructureIdPosition.md)
 - [ESIClient::GetUniverseSystemJumps200Ok](docs/GetUniverseSystemJumps200Ok.md)
 - [ESIClient::GetUniverseSystemKills200Ok](docs/GetUniverseSystemKills200Ok.md)
 - [ESIClient::GetUniverseSystemsSystemIdNotFound](docs/GetUniverseSystemsSystemIdNotFound.md)
 - [ESIClient::GetUniverseSystemsSystemIdOk](docs/GetUniverseSystemsSystemIdOk.md)
 - [ESIClient::GetUniverseSystemsSystemIdPlanet](docs/GetUniverseSystemsSystemIdPlanet.md)
 - [ESIClient::GetUniverseSystemsSystemIdPosition](docs/GetUniverseSystemsSystemIdPosition.md)
 - [ESIClient::GetUniverseTypesTypeIdDogmaAttribute](docs/GetUniverseTypesTypeIdDogmaAttribute.md)
 - [ESIClient::GetUniverseTypesTypeIdDogmaEffect](docs/GetUniverseTypesTypeIdDogmaEffect.md)
 - [ESIClient::GetUniverseTypesTypeIdNotFound](docs/GetUniverseTypesTypeIdNotFound.md)
 - [ESIClient::GetUniverseTypesTypeIdOk](docs/GetUniverseTypesTypeIdOk.md)
 - [ESIClient::GetWarsWarIdAggressor](docs/GetWarsWarIdAggressor.md)
 - [ESIClient::GetWarsWarIdAlly](docs/GetWarsWarIdAlly.md)
 - [ESIClient::GetWarsWarIdDefender](docs/GetWarsWarIdDefender.md)
 - [ESIClient::GetWarsWarIdKillmails200Ok](docs/GetWarsWarIdKillmails200Ok.md)
 - [ESIClient::GetWarsWarIdKillmailsUnprocessableEntity](docs/GetWarsWarIdKillmailsUnprocessableEntity.md)
 - [ESIClient::GetWarsWarIdOk](docs/GetWarsWarIdOk.md)
 - [ESIClient::GetWarsWarIdUnprocessableEntity](docs/GetWarsWarIdUnprocessableEntity.md)
 - [ESIClient::InternalServerError](docs/InternalServerError.md)
 - [ESIClient::PostCharactersAffiliation200Ok](docs/PostCharactersAffiliation200Ok.md)
 - [ESIClient::PostCharactersAffiliationNotFound](docs/PostCharactersAffiliationNotFound.md)
 - [ESIClient::PostCharactersCharacterIdAssetsLocations200Ok](docs/PostCharactersCharacterIdAssetsLocations200Ok.md)
 - [ESIClient::PostCharactersCharacterIdAssetsLocationsPosition](docs/PostCharactersCharacterIdAssetsLocationsPosition.md)
 - [ESIClient::PostCharactersCharacterIdAssetsNames200Ok](docs/PostCharactersCharacterIdAssetsNames200Ok.md)
 - [ESIClient::PostCharactersCharacterIdFittingsCreated](docs/PostCharactersCharacterIdFittingsCreated.md)
 - [ESIClient::PostCharactersCharacterIdFittingsFitting](docs/PostCharactersCharacterIdFittingsFitting.md)
 - [ESIClient::PostCharactersCharacterIdFittingsItem](docs/PostCharactersCharacterIdFittingsItem.md)
 - [ESIClient::PostCharactersCharacterIdMailBadRequest](docs/PostCharactersCharacterIdMailBadRequest.md)
 - [ESIClient::PostCharactersCharacterIdMailLabelsLabel](docs/PostCharactersCharacterIdMailLabelsLabel.md)
 - [ESIClient::PostCharactersCharacterIdMailMail](docs/PostCharactersCharacterIdMailMail.md)
 - [ESIClient::PostCharactersCharacterIdMailRecipient](docs/PostCharactersCharacterIdMailRecipient.md)
 - [ESIClient::PostCorporationsCorporationIdAssetsLocations200Ok](docs/PostCorporationsCorporationIdAssetsLocations200Ok.md)
 - [ESIClient::PostCorporationsCorporationIdAssetsLocationsPosition](docs/PostCorporationsCorporationIdAssetsLocationsPosition.md)
 - [ESIClient::PostCorporationsCorporationIdAssetsNames200Ok](docs/PostCorporationsCorporationIdAssetsNames200Ok.md)
 - [ESIClient::PostFleetsFleetIdMembersInvitation](docs/PostFleetsFleetIdMembersInvitation.md)
 - [ESIClient::PostFleetsFleetIdMembersNotFound](docs/PostFleetsFleetIdMembersNotFound.md)
 - [ESIClient::PostFleetsFleetIdMembersUnprocessableEntity](docs/PostFleetsFleetIdMembersUnprocessableEntity.md)
 - [ESIClient::PostFleetsFleetIdWingsCreated](docs/PostFleetsFleetIdWingsCreated.md)
 - [ESIClient::PostFleetsFleetIdWingsNotFound](docs/PostFleetsFleetIdWingsNotFound.md)
 - [ESIClient::PostFleetsFleetIdWingsWingIdSquadsCreated](docs/PostFleetsFleetIdWingsWingIdSquadsCreated.md)
 - [ESIClient::PostFleetsFleetIdWingsWingIdSquadsNotFound](docs/PostFleetsFleetIdWingsWingIdSquadsNotFound.md)
 - [ESIClient::PostUiOpenwindowNewmailNewMail](docs/PostUiOpenwindowNewmailNewMail.md)
 - [ESIClient::PostUiOpenwindowNewmailUnprocessableEntity](docs/PostUiOpenwindowNewmailUnprocessableEntity.md)
 - [ESIClient::PostUniverseIdsAgent](docs/PostUniverseIdsAgent.md)
 - [ESIClient::PostUniverseIdsAlliance](docs/PostUniverseIdsAlliance.md)
 - [ESIClient::PostUniverseIdsCharacter](docs/PostUniverseIdsCharacter.md)
 - [ESIClient::PostUniverseIdsConstellation](docs/PostUniverseIdsConstellation.md)
 - [ESIClient::PostUniverseIdsCorporation](docs/PostUniverseIdsCorporation.md)
 - [ESIClient::PostUniverseIdsFaction](docs/PostUniverseIdsFaction.md)
 - [ESIClient::PostUniverseIdsInventoryType](docs/PostUniverseIdsInventoryType.md)
 - [ESIClient::PostUniverseIdsOk](docs/PostUniverseIdsOk.md)
 - [ESIClient::PostUniverseIdsRegion](docs/PostUniverseIdsRegion.md)
 - [ESIClient::PostUniverseIdsServiceUnavailable](docs/PostUniverseIdsServiceUnavailable.md)
 - [ESIClient::PostUniverseIdsStation](docs/PostUniverseIdsStation.md)
 - [ESIClient::PostUniverseIdsSystem](docs/PostUniverseIdsSystem.md)
 - [ESIClient::PostUniverseNames200Ok](docs/PostUniverseNames200Ok.md)
 - [ESIClient::PostUniverseNamesNotFound](docs/PostUniverseNamesNotFound.md)
 - [ESIClient::PutCharactersCharacterIdCalendarEventIdResponse](docs/PutCharactersCharacterIdCalendarEventIdResponse.md)
 - [ESIClient::PutCharactersCharacterIdMailMailIdBadRequest](docs/PutCharactersCharacterIdMailMailIdBadRequest.md)
 - [ESIClient::PutCharactersCharacterIdMailMailIdContents](docs/PutCharactersCharacterIdMailMailIdContents.md)
 - [ESIClient::PutFleetsFleetIdBadRequest](docs/PutFleetsFleetIdBadRequest.md)
 - [ESIClient::PutFleetsFleetIdMembersMemberIdMovement](docs/PutFleetsFleetIdMembersMemberIdMovement.md)
 - [ESIClient::PutFleetsFleetIdMembersMemberIdNotFound](docs/PutFleetsFleetIdMembersMemberIdNotFound.md)
 - [ESIClient::PutFleetsFleetIdMembersMemberIdUnprocessableEntity](docs/PutFleetsFleetIdMembersMemberIdUnprocessableEntity.md)
 - [ESIClient::PutFleetsFleetIdNewSettings](docs/PutFleetsFleetIdNewSettings.md)
 - [ESIClient::PutFleetsFleetIdNotFound](docs/PutFleetsFleetIdNotFound.md)
 - [ESIClient::PutFleetsFleetIdSquadsSquadIdNaming](docs/PutFleetsFleetIdSquadsSquadIdNaming.md)
 - [ESIClient::PutFleetsFleetIdSquadsSquadIdNotFound](docs/PutFleetsFleetIdSquadsSquadIdNotFound.md)
 - [ESIClient::PutFleetsFleetIdWingsWingIdNaming](docs/PutFleetsFleetIdWingsWingIdNaming.md)
 - [ESIClient::PutFleetsFleetIdWingsWingIdNotFound](docs/PutFleetsFleetIdWingsWingIdNotFound.md)


## Documentation for Authorization


### evesso

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: https://login.eveonline.com/oauth/authorize
- **Scopes**: 
  - esi-alliances.read_contacts.v1: EVE SSO scope esi-alliances.read_contacts.v1
  - esi-assets.read_assets.v1: EVE SSO scope esi-assets.read_assets.v1
  - esi-assets.read_corporation_assets.v1: EVE SSO scope esi-assets.read_corporation_assets.v1
  - esi-bookmarks.read_character_bookmarks.v1: EVE SSO scope esi-bookmarks.read_character_bookmarks.v1
  - esi-bookmarks.read_corporation_bookmarks.v1: EVE SSO scope esi-bookmarks.read_corporation_bookmarks.v1
  - esi-calendar.read_calendar_events.v1: EVE SSO scope esi-calendar.read_calendar_events.v1
  - esi-calendar.respond_calendar_events.v1: EVE SSO scope esi-calendar.respond_calendar_events.v1
  - esi-characters.read_agents_research.v1: EVE SSO scope esi-characters.read_agents_research.v1
  - esi-characters.read_blueprints.v1: EVE SSO scope esi-characters.read_blueprints.v1
  - esi-characters.read_chat_channels.v1: EVE SSO scope esi-characters.read_chat_channels.v1
  - esi-characters.read_contacts.v1: EVE SSO scope esi-characters.read_contacts.v1
  - esi-characters.read_corporation_roles.v1: EVE SSO scope esi-characters.read_corporation_roles.v1
  - esi-characters.read_fatigue.v1: EVE SSO scope esi-characters.read_fatigue.v1
  - esi-characters.read_fw_stats.v1: EVE SSO scope esi-characters.read_fw_stats.v1
  - esi-characters.read_loyalty.v1: EVE SSO scope esi-characters.read_loyalty.v1
  - esi-characters.read_medals.v1: EVE SSO scope esi-characters.read_medals.v1
  - esi-characters.read_notifications.v1: EVE SSO scope esi-characters.read_notifications.v1
  - esi-characters.read_opportunities.v1: EVE SSO scope esi-characters.read_opportunities.v1
  - esi-characters.read_standings.v1: EVE SSO scope esi-characters.read_standings.v1
  - esi-characters.read_titles.v1: EVE SSO scope esi-characters.read_titles.v1
  - esi-characters.write_contacts.v1: EVE SSO scope esi-characters.write_contacts.v1
  - esi-characterstats.read.v1: EVE SSO scope esi-characterstats.read.v1
  - esi-clones.read_clones.v1: EVE SSO scope esi-clones.read_clones.v1
  - esi-clones.read_implants.v1: EVE SSO scope esi-clones.read_implants.v1
  - esi-contracts.read_character_contracts.v1: EVE SSO scope esi-contracts.read_character_contracts.v1
  - esi-contracts.read_corporation_contracts.v1: EVE SSO scope esi-contracts.read_corporation_contracts.v1
  - esi-corporations.read_blueprints.v1: EVE SSO scope esi-corporations.read_blueprints.v1
  - esi-corporations.read_contacts.v1: EVE SSO scope esi-corporations.read_contacts.v1
  - esi-corporations.read_container_logs.v1: EVE SSO scope esi-corporations.read_container_logs.v1
  - esi-corporations.read_corporation_membership.v1: EVE SSO scope esi-corporations.read_corporation_membership.v1
  - esi-corporations.read_divisions.v1: EVE SSO scope esi-corporations.read_divisions.v1
  - esi-corporations.read_facilities.v1: EVE SSO scope esi-corporations.read_facilities.v1
  - esi-corporations.read_fw_stats.v1: EVE SSO scope esi-corporations.read_fw_stats.v1
  - esi-corporations.read_medals.v1: EVE SSO scope esi-corporations.read_medals.v1
  - esi-corporations.read_outposts.v1: EVE SSO scope esi-corporations.read_outposts.v1
  - esi-corporations.read_standings.v1: EVE SSO scope esi-corporations.read_standings.v1
  - esi-corporations.read_starbases.v1: EVE SSO scope esi-corporations.read_starbases.v1
  - esi-corporations.read_structures.v1: EVE SSO scope esi-corporations.read_structures.v1
  - esi-corporations.read_titles.v1: EVE SSO scope esi-corporations.read_titles.v1
  - esi-corporations.track_members.v1: EVE SSO scope esi-corporations.track_members.v1
  - esi-fittings.read_fittings.v1: EVE SSO scope esi-fittings.read_fittings.v1
  - esi-fittings.write_fittings.v1: EVE SSO scope esi-fittings.write_fittings.v1
  - esi-fleets.read_fleet.v1: EVE SSO scope esi-fleets.read_fleet.v1
  - esi-fleets.write_fleet.v1: EVE SSO scope esi-fleets.write_fleet.v1
  - esi-industry.read_character_jobs.v1: EVE SSO scope esi-industry.read_character_jobs.v1
  - esi-industry.read_character_mining.v1: EVE SSO scope esi-industry.read_character_mining.v1
  - esi-industry.read_corporation_jobs.v1: EVE SSO scope esi-industry.read_corporation_jobs.v1
  - esi-industry.read_corporation_mining.v1: EVE SSO scope esi-industry.read_corporation_mining.v1
  - esi-killmails.read_corporation_killmails.v1: EVE SSO scope esi-killmails.read_corporation_killmails.v1
  - esi-killmails.read_killmails.v1: EVE SSO scope esi-killmails.read_killmails.v1
  - esi-location.read_location.v1: EVE SSO scope esi-location.read_location.v1
  - esi-location.read_online.v1: EVE SSO scope esi-location.read_online.v1
  - esi-location.read_ship_type.v1: EVE SSO scope esi-location.read_ship_type.v1
  - esi-mail.organize_mail.v1: EVE SSO scope esi-mail.organize_mail.v1
  - esi-mail.read_mail.v1: EVE SSO scope esi-mail.read_mail.v1
  - esi-mail.send_mail.v1: EVE SSO scope esi-mail.send_mail.v1
  - esi-markets.read_character_orders.v1: EVE SSO scope esi-markets.read_character_orders.v1
  - esi-markets.read_corporation_orders.v1: EVE SSO scope esi-markets.read_corporation_orders.v1
  - esi-markets.structure_markets.v1: EVE SSO scope esi-markets.structure_markets.v1
  - esi-planets.manage_planets.v1: EVE SSO scope esi-planets.manage_planets.v1
  - esi-planets.read_customs_offices.v1: EVE SSO scope esi-planets.read_customs_offices.v1
  - esi-search.search_structures.v1: EVE SSO scope esi-search.search_structures.v1
  - esi-skills.read_skillqueue.v1: EVE SSO scope esi-skills.read_skillqueue.v1
  - esi-skills.read_skills.v1: EVE SSO scope esi-skills.read_skills.v1
  - esi-ui.open_window.v1: EVE SSO scope esi-ui.open_window.v1
  - esi-ui.write_waypoint.v1: EVE SSO scope esi-ui.write_waypoint.v1
  - esi-universe.read_structures.v1: EVE SSO scope esi-universe.read_structures.v1
  - esi-wallet.read_character_wallet.v1: EVE SSO scope esi-wallet.read_character_wallet.v1
  - esi-wallet.read_corporation_wallets.v1: EVE SSO scope esi-wallet.read_corporation_wallets.v1

