# ESIClient::AssetsApi

All URIs are relative to *https://esi.tech.ccp.is*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get_characters_character_id_assets**](AssetsApi.md#get_characters_character_id_assets) | **GET** /v3/characters/{character_id}/assets/ | Get character assets
[**get_corporations_corporation_id_assets**](AssetsApi.md#get_corporations_corporation_id_assets) | **GET** /v2/corporations/{corporation_id}/assets/ | Get corporation assets
[**post_characters_character_id_assets_locations**](AssetsApi.md#post_characters_character_id_assets_locations) | **POST** /v2/characters/{character_id}/assets/locations/ | Get character asset locations
[**post_characters_character_id_assets_names**](AssetsApi.md#post_characters_character_id_assets_names) | **POST** /v1/characters/{character_id}/assets/names/ | Get character asset names
[**post_corporations_corporation_id_assets_locations**](AssetsApi.md#post_corporations_corporation_id_assets_locations) | **POST** /v2/corporations/{corporation_id}/assets/locations/ | Get corporation asset locations
[**post_corporations_corporation_id_assets_names**](AssetsApi.md#post_corporations_corporation_id_assets_names) | **POST** /v1/corporations/{corporation_id}/assets/names/ | Get coporation asset names


# **get_characters_character_id_assets**
> Array&lt;GetCharactersCharacterIdAssets200Ok&gt; get_characters_character_id_assets(character_id, opts)

Get character assets

Return a list of the characters assets  ---  This route is cached for up to 3600 seconds

### Example
```ruby
# load the gem
require 'esi_client'
# setup authorization
ESIClient.configure do |config|
  # Configure OAuth2 access token for authorization: evesso
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = ESIClient::AssetsApi.new

character_id = 56 # Integer | An EVE character ID

opts = { 
  datasource: 'tranquility', # String | The server name you would like data from
  page: 1, # Integer | Which page of results to return
  token: 'token_example', # String | Access token to use if unable to set a header
  user_agent: 'user_agent_example', # String | Client identifier, takes precedence over headers
  x_user_agent: 'x_user_agent_example' # String | Client identifier, takes precedence over User-Agent
}

begin
  #Get character assets
  result = api_instance.get_characters_character_id_assets(character_id, opts)
  p result
rescue ESIClient::ApiError => e
  puts "Exception when calling AssetsApi->get_characters_character_id_assets: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **character_id** | **Integer**| An EVE character ID | 
 **datasource** | **String**| The server name you would like data from | [optional] [default to tranquility]
 **page** | **Integer**| Which page of results to return | [optional] [default to 1]
 **token** | **String**| Access token to use if unable to set a header | [optional] 
 **user_agent** | **String**| Client identifier, takes precedence over headers | [optional] 
 **x_user_agent** | **String**| Client identifier, takes precedence over User-Agent | [optional] 

### Return type

[**Array&lt;GetCharactersCharacterIdAssets200Ok&gt;**](GetCharactersCharacterIdAssets200Ok.md)

### Authorization

[evesso](../README.md#evesso)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_corporations_corporation_id_assets**
> Array&lt;GetCorporationsCorporationIdAssets200Ok&gt; get_corporations_corporation_id_assets(corporation_id, , opts)

Get corporation assets

Return a list of the corporation assets  ---  This route is cached for up to 3600 seconds  --- Requires one of the following EVE corporation role(s): Director  --- [This route has an available update](https://esi.tech.ccp.is/diff/latest/dev/#GET-/corporations/{corporation_id}/assets/)

### Example
```ruby
# load the gem
require 'esi_client'
# setup authorization
ESIClient.configure do |config|
  # Configure OAuth2 access token for authorization: evesso
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = ESIClient::AssetsApi.new

corporation_id = 56 # Integer | An EVE corporation ID

opts = { 
  datasource: 'tranquility', # String | The server name you would like data from
  page: 1, # Integer | Which page of results to return
  token: 'token_example', # String | Access token to use if unable to set a header
  user_agent: 'user_agent_example', # String | Client identifier, takes precedence over headers
  x_user_agent: 'x_user_agent_example' # String | Client identifier, takes precedence over User-Agent
}

begin
  #Get corporation assets
  result = api_instance.get_corporations_corporation_id_assets(corporation_id, , opts)
  p result
rescue ESIClient::ApiError => e
  puts "Exception when calling AssetsApi->get_corporations_corporation_id_assets: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **corporation_id** | **Integer**| An EVE corporation ID | 
 **datasource** | **String**| The server name you would like data from | [optional] [default to tranquility]
 **page** | **Integer**| Which page of results to return | [optional] [default to 1]
 **token** | **String**| Access token to use if unable to set a header | [optional] 
 **user_agent** | **String**| Client identifier, takes precedence over headers | [optional] 
 **x_user_agent** | **String**| Client identifier, takes precedence over User-Agent | [optional] 

### Return type

[**Array&lt;GetCorporationsCorporationIdAssets200Ok&gt;**](GetCorporationsCorporationIdAssets200Ok.md)

### Authorization

[evesso](../README.md#evesso)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **post_characters_character_id_assets_locations**
> Array&lt;PostCharactersCharacterIdAssetsLocations200Ok&gt; post_characters_character_id_assets_locations(character_iditem_ids, opts)

Get character asset locations

Return locations for a set of item ids, which you can get from character assets endpoint. Coordinates for items in hangars or stations are set to (0,0,0)  --- 

### Example
```ruby
# load the gem
require 'esi_client'
# setup authorization
ESIClient.configure do |config|
  # Configure OAuth2 access token for authorization: evesso
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = ESIClient::AssetsApi.new

character_id = 56 # Integer | An EVE character ID

item_ids = [ESIClient::Array<Integer>.new] # Array<Integer> | A list of item ids

opts = { 
  datasource: 'tranquility', # String | The server name you would like data from
  token: 'token_example', # String | Access token to use if unable to set a header
  user_agent: 'user_agent_example', # String | Client identifier, takes precedence over headers
  x_user_agent: 'x_user_agent_example' # String | Client identifier, takes precedence over User-Agent
}

begin
  #Get character asset locations
  result = api_instance.post_characters_character_id_assets_locations(character_iditem_ids, opts)
  p result
rescue ESIClient::ApiError => e
  puts "Exception when calling AssetsApi->post_characters_character_id_assets_locations: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **character_id** | **Integer**| An EVE character ID | 
 **item_ids** | **Array&lt;Integer&gt;**| A list of item ids | 
 **datasource** | **String**| The server name you would like data from | [optional] [default to tranquility]
 **token** | **String**| Access token to use if unable to set a header | [optional] 
 **user_agent** | **String**| Client identifier, takes precedence over headers | [optional] 
 **x_user_agent** | **String**| Client identifier, takes precedence over User-Agent | [optional] 

### Return type

[**Array&lt;PostCharactersCharacterIdAssetsLocations200Ok&gt;**](PostCharactersCharacterIdAssetsLocations200Ok.md)

### Authorization

[evesso](../README.md#evesso)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **post_characters_character_id_assets_names**
> Array&lt;PostCharactersCharacterIdAssetsNames200Ok&gt; post_characters_character_id_assets_names(character_iditem_ids, opts)

Get character asset names

Return names for a set of item ids, which you can get from character assets endpoint. Typically used for items that can customize names, like containers or ships.  --- 

### Example
```ruby
# load the gem
require 'esi_client'
# setup authorization
ESIClient.configure do |config|
  # Configure OAuth2 access token for authorization: evesso
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = ESIClient::AssetsApi.new

character_id = 56 # Integer | An EVE character ID

item_ids = [ESIClient::Array<Integer>.new] # Array<Integer> | A list of item ids

opts = { 
  datasource: 'tranquility', # String | The server name you would like data from
  token: 'token_example', # String | Access token to use if unable to set a header
  user_agent: 'user_agent_example', # String | Client identifier, takes precedence over headers
  x_user_agent: 'x_user_agent_example' # String | Client identifier, takes precedence over User-Agent
}

begin
  #Get character asset names
  result = api_instance.post_characters_character_id_assets_names(character_iditem_ids, opts)
  p result
rescue ESIClient::ApiError => e
  puts "Exception when calling AssetsApi->post_characters_character_id_assets_names: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **character_id** | **Integer**| An EVE character ID | 
 **item_ids** | **Array&lt;Integer&gt;**| A list of item ids | 
 **datasource** | **String**| The server name you would like data from | [optional] [default to tranquility]
 **token** | **String**| Access token to use if unable to set a header | [optional] 
 **user_agent** | **String**| Client identifier, takes precedence over headers | [optional] 
 **x_user_agent** | **String**| Client identifier, takes precedence over User-Agent | [optional] 

### Return type

[**Array&lt;PostCharactersCharacterIdAssetsNames200Ok&gt;**](PostCharactersCharacterIdAssetsNames200Ok.md)

### Authorization

[evesso](../README.md#evesso)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **post_corporations_corporation_id_assets_locations**
> Array&lt;PostCorporationsCorporationIdAssetsLocations200Ok&gt; post_corporations_corporation_id_assets_locations(corporation_id, item_ids, opts)

Get corporation asset locations

Return locations for a set of item ids, which you can get from corporation assets endpoint. Coordinates for items in hangars or stations are set to (0,0,0)  ---  Requires one of the following EVE corporation role(s): Director

### Example
```ruby
# load the gem
require 'esi_client'
# setup authorization
ESIClient.configure do |config|
  # Configure OAuth2 access token for authorization: evesso
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = ESIClient::AssetsApi.new

corporation_id = 56 # Integer | An EVE corporation ID

item_ids = [ESIClient::Array<Integer>.new] # Array<Integer> | A list of item ids

opts = { 
  datasource: 'tranquility', # String | The server name you would like data from
  token: 'token_example', # String | Access token to use if unable to set a header
  user_agent: 'user_agent_example', # String | Client identifier, takes precedence over headers
  x_user_agent: 'x_user_agent_example' # String | Client identifier, takes precedence over User-Agent
}

begin
  #Get corporation asset locations
  result = api_instance.post_corporations_corporation_id_assets_locations(corporation_id, item_ids, opts)
  p result
rescue ESIClient::ApiError => e
  puts "Exception when calling AssetsApi->post_corporations_corporation_id_assets_locations: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **corporation_id** | **Integer**| An EVE corporation ID | 
 **item_ids** | **Array&lt;Integer&gt;**| A list of item ids | 
 **datasource** | **String**| The server name you would like data from | [optional] [default to tranquility]
 **token** | **String**| Access token to use if unable to set a header | [optional] 
 **user_agent** | **String**| Client identifier, takes precedence over headers | [optional] 
 **x_user_agent** | **String**| Client identifier, takes precedence over User-Agent | [optional] 

### Return type

[**Array&lt;PostCorporationsCorporationIdAssetsLocations200Ok&gt;**](PostCorporationsCorporationIdAssetsLocations200Ok.md)

### Authorization

[evesso](../README.md#evesso)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **post_corporations_corporation_id_assets_names**
> Array&lt;PostCorporationsCorporationIdAssetsNames200Ok&gt; post_corporations_corporation_id_assets_names(corporation_id, item_ids, opts)

Get coporation asset names

Return names for a set of item ids, which you can get from corporation assets endpoint. Only valid for items that can customize names, like containers or ships.  ---  Requires one of the following EVE corporation role(s): Director

### Example
```ruby
# load the gem
require 'esi_client'
# setup authorization
ESIClient.configure do |config|
  # Configure OAuth2 access token for authorization: evesso
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = ESIClient::AssetsApi.new

corporation_id = 56 # Integer | An EVE corporation ID

item_ids = [ESIClient::Array<Integer>.new] # Array<Integer> | A list of item ids

opts = { 
  datasource: 'tranquility', # String | The server name you would like data from
  token: 'token_example', # String | Access token to use if unable to set a header
  user_agent: 'user_agent_example', # String | Client identifier, takes precedence over headers
  x_user_agent: 'x_user_agent_example' # String | Client identifier, takes precedence over User-Agent
}

begin
  #Get coporation asset names
  result = api_instance.post_corporations_corporation_id_assets_names(corporation_id, item_ids, opts)
  p result
rescue ESIClient::ApiError => e
  puts "Exception when calling AssetsApi->post_corporations_corporation_id_assets_names: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **corporation_id** | **Integer**| An EVE corporation ID | 
 **item_ids** | **Array&lt;Integer&gt;**| A list of item ids | 
 **datasource** | **String**| The server name you would like data from | [optional] [default to tranquility]
 **token** | **String**| Access token to use if unable to set a header | [optional] 
 **user_agent** | **String**| Client identifier, takes precedence over headers | [optional] 
 **x_user_agent** | **String**| Client identifier, takes precedence over User-Agent | [optional] 

### Return type

[**Array&lt;PostCorporationsCorporationIdAssetsNames200Ok&gt;**](PostCorporationsCorporationIdAssetsNames200Ok.md)

### Authorization

[evesso](../README.md#evesso)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



